/**
 * YakiToFileSystem.java
 */

package net.yakiboo.yakito.io;

import net.yakiboo.yakito.YakiToNoContainersException;
import net.yakiboo.yakito.io.YakiToOutput;

import java.io.BufferedInputStream;
import java.io.BufferedOutputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.net.URISyntaxException;
import java.util.zip.ZipEntry;
import java.util.zip.ZipFile;
import java.util.zip.ZipInputStream;

/**
 * Clase de utilidades estaticas referentes al sistema de ficheros
 * 
 * @author Sergio Garcia Mondaray
 */
public class YakiToFileSystem {

	private static File jarLocation = null;
	private static File langLocation = null;
	private static File profilesLocation = null;
	private static File configFile = null;
	private static File containersFile = null;

	/**
	 * Encuentra el directorio en el que esta localizado el JAR de la aplicacion
	 * 
	 * @return Directorio donde se encuentra el JAR que se esta ejecutando
	 */
	public static File getJarLocation() {
		if (jarLocation == null) {
			File location = null;
			try {
				File jarFile = new File(net.yakiboo.yakito.YakiToApp.class
						.getProtectionDomain().getCodeSource().getLocation()
						.toURI());
				location = jarFile.getParentFile();
				YakiToOutput.message("Localizada ubicación del ejecutable: "
						+ location.getAbsolutePath());
			} catch (URISyntaxException ex) {
				YakiToOutput
						.error("No pudo determinarse la ruta del ejecutable");
			}
			jarLocation = location;
			return location;
		} else {
			return jarLocation;
		}
	}

	/**
	 * Obtiene la ubicacion del directorio de idiomas dentro del sistema de
	 * archivos
	 * 
	 * @return Directorio donde se encuentran los archivos de idioma
	 */
	public static File getLangLocation() {
		if (langLocation == null) {
			File jarLocation = getJarLocation();
			File langLoc = new File(jarLocation.getAbsolutePath() + "/lang");
			if (langLoc.exists()) {
				YakiToOutput
						.message("Localizada la ubicación de los archivos de idioma: "
								+ langLoc.getAbsolutePath());
				langLocation = langLoc;
				return langLoc;
			} else {
				YakiToOutput
						.error("No se encuentra el directorio de archivos de idioma ("
								+ langLoc + "). Por favor, reestablezcalo.");
				langLocation = null;
				return null;
			}
		} else {
			return langLocation;
		}
	}

	/**
	 * Obtiene la ubicacion del directorio de perfiles dentro del sistema de
	 * archivos
	 * 
	 * @return Directorio donde se encuentran los perfiles de conversion
	 */
	public static File getProfilesLocation() {
		if (profilesLocation == null) {
			File jarLocation = getJarLocation();
			File profLocation = new File(jarLocation.getAbsolutePath()
					+ "/profiles");
			if (profLocation.exists()) {
				YakiToOutput
						.message("Localizada la ubicación de los perfiles de "
								+ "conversión: "
								+ profLocation.getAbsolutePath());
				profilesLocation = profLocation;
				return profLocation;
			} else {
				YakiToOutput
						.error("No se encuentra el directorio de perfiles ("
								+ profLocation
								+ "). Por favor, reestablezcalo.");
				profilesLocation = null;
				return null;
			}
		} else {
			return profilesLocation;
		}
	}

	/**
	 * Obtiene el fichero de configuracion de YakiTo, en el que se almacenan los
	 * parametros de la ultima ejecucion. Tengase en cuenta que dicho archivo
	 * puede no existir (si es la primera vez que se ejecuta el programa)
	 * 
	 * @return Fichero de configuracion.
	 */
	public static File getConfigFile() {
		if (configFile == null) {
			File jarLocation = getJarLocation();
			File config = new File(/*jarLocation.getAbsolutePath()*/ System.getProperty("user.home") 
					+ System.getProperty("file.separator") + "yakito.cfg");
			configFile = config;
			return config;			
		} else {
			return configFile;
		}
	}

	/**
	 * Obtiene el archivo XML de contenedores multimedia
	 * @return Archivo de contenedores
	 */
	public static File getContainersFile() throws YakiToNoContainersException{
		if (containersFile == null) {
			File jarLocation = getJarLocation();
			File cont = new File(jarLocation.getAbsolutePath()
					+ "/ffmpeg/containers.xml");
			if (cont.exists()) {
				YakiToOutput.message("Localizado el archivo de contenedores: "
						+ cont.getAbsolutePath());
				containersFile = cont;
				return containersFile;
			} else {
				throw new YakiToNoContainersException();
			}
		} else {
			return containersFile;
		}
	}

	/**
	 * TODO: Hacer que este metodo descomprima bien. Ahora no funciona
	 * Descomprime un fichero ZIP en una ruta especificada
	 * 
	 * @param zipFile
	 *            Archivo comprimido en formato ZIP
	 * @param path
	 *            Ruta donde extraer el contenido del archivo ZIP
	 */
	public static void unzipFile(File zip, String path) {
		// Creamos el directorio de destino
		File destiny = new File(path);
		destiny.mkdir();
		// Descomprimimos el ZIP en esa ruta de destino

		int BUFFER_SIZE = 2048;

		try {
			// crear un ZipInputStream para leer el fichero zip
			FileInputStream fis = new FileInputStream(path + File.separator
					+ zip);
			ZipInputStream zis = new ZipInputStream(
					new BufferedInputStream(fis));
			ZipEntry entry;
			// crear un bucle para recorrer todos los archivos del zip
			while ((entry = zis.getNextEntry()) != null) {
				System.out.println("Procesando " + entry.getName());
				File file = new File(destiny.getAbsolutePath() + File.separator
						+ entry.getName());
				ZipFile zipFile = new ZipFile(zip);
				if (!entry.isDirectory()) {
					BufferedInputStream bis = new BufferedInputStream(
							zipFile.getInputStream(entry), BUFFER_SIZE);
					String parentName;
					if ((parentName = file.getParent()) != null) {
						File dire = new File(parentName);
						// File dire = new File(ficheros[i] +
						// parentName);
						dire.mkdirs();
					}
					BufferedOutputStream dest = new BufferedOutputStream(
							new FileOutputStream(file), BUFFER_SIZE);
					int cont;
					while ((cont = bis.read()) != -1) {
						dest.write(cont);
					}
					bis.close();
					dest.close();
				} else {
					file.mkdirs();
				}
				entry = zis.getNextEntry();
			}
			zis.close();
			YakiToOutput.error("No se pudo descomprimir el fichero \""
					+ zip.getAbsolutePath() + "\". Ocurrió un error.");
		} catch (Exception exc) {
			YakiToOutput.message("Se ha descomprimido el fichero \""
					+ zip.getAbsolutePath() + "\" con éxito");
		}
	}

	/**
	 * Descomprime un fichero ZIP en el directorio donde se encuentre
	 * 
	 * @param zipFile
	 *            Archivo comprimido en formato ZIP
	 */
	public static void unzipFile(File zipFile) {
		unzipFile(zipFile, zipFile.getParent());
	}

}
