/*
 * YakiToView.java
 */

package net.yakiboo.yakito.view;

import org.jdesktop.application.Action;
import org.jdesktop.application.ResourceMap;
import org.jdesktop.application.SingleFrameApplication;
import org.jdesktop.application.FrameView;
import org.jdesktop.application.TaskMonitor;

import java.awt.Color;
import java.awt.Component;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.File;
import java.util.HashMap;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;

import javax.swing.BorderFactory;
import javax.swing.Box;
import javax.swing.JButton;
import javax.swing.JComponent;
import javax.swing.JFileChooser;
import javax.swing.JMenu;
import javax.swing.JMenuItem;
import javax.swing.JOptionPane;
import javax.swing.JProgressBar;
import javax.swing.JTextField;
import javax.swing.SwingUtilities;
import javax.swing.Timer;
import javax.swing.Icon;
import javax.swing.JRadioButton;
import javax.swing.JCheckBox;
import javax.swing.JDialog;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.table.DefaultTableModel;

import net.yakiboo.yakito.YakiToApp;
import net.yakiboo.yakito.YakiToCodec;
import net.yakiboo.yakito.YakiToContainer;
import net.yakiboo.yakito.YakiToConversion;
import net.yakiboo.yakito.YakiToProfile;
import net.yakiboo.yakito.YakiToConversion.Mode;
import net.yakiboo.yakito.YakiToConversion.Redim;
import net.yakiboo.yakito.YakiToNoContainersException;
import sun.org.mozilla.javascript.tools.debugger.SwingGui;

import net.yakiboo.yakito.config.YakiToConfig;
import net.yakiboo.yakito.io.YakiToFileSystem;
import net.yakiboo.yakito.io.YakiToOutput;
import net.yakiboo.yakito.io.YakiToXMLSyntaxException;
import net.yakiboo.yakito.language.YakiToLanguage;
import net.yakiboo.yakito.language.YakiToNoLanguagesException;
import net.yakiboo.yakito.utils.FileDrop;
import net.yakiboo.yakito.utils.ProgressRenderer;
import net.yakiboo.yakito.utils.Utils;
import net.yakiboo.yakito.utils.YakiToRowRenderer;

/**
 * The application's main frame.
 */
public class YakiToView extends FrameView implements YakiToViewFiledrop,
		TableUpdater {

	private static final String CHANNELS_MONO = "1 (Mono)";
	private static final String CHANNELS_STEREO = "2 (Stereo)";

	/**
	 * Estado del proceso de recodificacion. Sera false cuando no se esten
	 * recodificando videos, y true en caso contrario.
	 */
	private boolean recoding = false;

	/**
	 * Configuracion de la aplicacion
	 */
	private YakiToConfig config = null;

	/**
	 * Parametros de conversion
	 */
	private YakiToConversion conversion = null;
	/**
	 * Menu de idiomas
	 */
	private JMenu langMenu = null;

	private DefaultTableModel tableModel;

	private boolean paused;

	/**
	 * Constructor principal
	 * 
	 * @param app
	 *            Aplicacion principal
	 * @param config
	 *            Objeto de configuracion
	 */
	public YakiToView(SingleFrameApplication app, YakiToConfig config)
			throws YakiToNoLanguagesException, YakiToNoContainersException {

		super(app);

		this.config = config;
		this.conversion = new YakiToConversion(this, config);
		this.conversion.loadLastParameters(config);

		initComponents();

		String dest = (config.getLastDestiny() == null) ? (System
				.getProperty("user.home")) : (config.getLastDestiny()
				.getAbsolutePath());
		jTextField1.setText(dest);

		this.getFrame().setSize(900, 600);

		// status bar initialization - message timeout, idle icon and busy
		// animation, etc
		ResourceMap resourceMap = getResourceMap();
		int messageTimeout = resourceMap.getInteger("StatusBar.messageTimeout");
		messageTimer = new Timer(messageTimeout, new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				statusMessageLabel.setText("Convirtiendo");
			}
		});
		messageTimer.setRepeats(false);
		int busyAnimationRate = resourceMap
				.getInteger("StatusBar.busyAnimationRate");
		for (int i = 0; i < busyIcons.length; i++) {
			busyIcons[i] = resourceMap
					.getIcon("StatusBar.busyIcons[" + i + "]");
		}
		busyIconTimer = new Timer(busyAnimationRate, new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				busyIconIndex = (busyIconIndex + 1) % busyIcons.length;
				statusAnimationLabel.setIcon(busyIcons[busyIconIndex]);
			}
		});
		idleIcon = resourceMap.getIcon("StatusBar.idleIcon");
		statusAnimationLabel.setIcon(idleIcon);
		progressBar.setVisible(false);

		// connecting action tasks to status bar via TaskMonitor
		TaskMonitor taskMonitor = new TaskMonitor(getApplication().getContext());
		taskMonitor
				.addPropertyChangeListener(new java.beans.PropertyChangeListener() {
					public void propertyChange(
							java.beans.PropertyChangeEvent evt) {
						String propertyName = evt.getPropertyName();
						if ("started".equals(propertyName)) {
							if (!busyIconTimer.isRunning()) {
								statusAnimationLabel.setIcon(busyIcons[0]);
								busyIconIndex = 0;
								busyIconTimer.start();
							}
							progressBar.setVisible(true);
							progressBar.setIndeterminate(true);
						} else if ("done".equals(propertyName)) {
							busyIconTimer.stop();
							statusAnimationLabel.setIcon(idleIcon);
							progressBar.setVisible(false);
							progressBar.setValue(0);
						} else if ("message".equals(propertyName)) {
							String text = (String) (evt.getNewValue());
							statusMessageLabel.setText((text == null) ? ""
									: text);
							messageTimer.restart();
						} else if ("progress".equals(propertyName)) {
							int value = (Integer) (evt.getNewValue());
							progressBar.setVisible(true);
							progressBar.setIndeterminate(false);
							progressBar.setValue(value);
						}
					}
				});

		levelLog();

		// Generamos el menu de idiomas de la derecha
		genLangMenu();
		// Establecemos las cadenas de texto de la interfaz
		updateLanguage();
		// Rellenamos los combos
		fillCombos();

	}

	private void fillCombos() throws YakiToNoContainersException {
		// Combo de contenedores multimedia
		fillComboContainers();		
		// Combo de codecs de audio y video
		fillComboACodecs();
		fillComboVCodecs();
		// Combo de canales de audio
		fillComboAchannels();
		// Combo de frecuencia de audio
		fillComboAfreq();
		// Combo de redimensionado
		fillComboRedim();
		// Combo de perfiles (Esta llamada debe ser la última)
		fillComboProfiles();
	}

	private void fillComboProfiles() {
		combo_profile.removeAllItems();
		combo_profile.addItem(config.getLanguage().getValueOf("custom"));
		Map<Object, Icon> images = new HashMap<Object, Icon>();
		for (YakiToProfile p : YakiToProfile.getAllProfiles()) {
			combo_profile.addItem(p);
			if (p.getImage() != null)
				images.put(p, p.getImage());
		}
		combo_profile.setRenderer(new IconListRenderer(images));
		// Intentamos seleccionar el perfil que se utilizo en la ultima sesion
		if (config.getLast_profile() != null) {
			YakiToProfile aux = new YakiToProfile(config.getLast_profile());
			YakiToOutput
					.message("Detectado el perfil utilizado en la ultima sesión: "
							+ aux.getName());
			combo_profile.setSelectedItem(aux);
		}
	}

	private void fillComboRedim() {
		combo_redim.removeAllItems();
		String s = config.getLanguage().getValueOf("custom");
		combo_redim.addItem(s);
		/*
		 * combo_redim.addItem("16:9"); combo_redim.addItem("4:3");
		 * combo_redim.addItem("3:2"); combo_redim.addItem("1.85");
		 * combo_redim.addItem("2.21"); combo_redim.addItem("2.39");
		 */
	}

	private void fillComboAfreq() {
		combo_afreq.removeAllItems();
		combo_afreq.addItem(22050);
		combo_afreq.addItem(32000);
		combo_afreq.addItem(44100);
		combo_afreq.addItem(50000);
		combo_afreq.addItem(60000);
		combo_afreq.addItem(192400);

	}

	private void fillComboAchannels() {
		combo_achannels.removeAllItems();
		combo_achannels.addItem(this.CHANNELS_MONO);
		combo_achannels.addItem(this.CHANNELS_STEREO);
		combo_achannels.setSelectedIndex(1);
	}

	private void fillComboContainers() throws YakiToNoContainersException {
		combo_container.removeAllItems();
		for (YakiToContainer c : YakiToContainer.listAvailableContainers()) {
			combo_container.addItem(c);
		}
	}

	private void enableOrDisableAudioParameters(boolean enable) {
		combo_acodec.setEnabled(enable);
		combo_achannels.setEnabled(enable);
		combo_afreq.setEnabled(enable);
		spinner_akbps.setEnabled(enable);
		slider_volume.setEnabled(enable);
	}

	private void enableOrDisableVideoParameters(boolean enable) {
		combo_vcodec.setEnabled(enable);
		combo_vcodec.setEnabled(enable);
		combo_vtag.setEnabled(enable);
		combo_redim.setEnabled(enable && check_redim.isSelected());
		spinner_fps.setEnabled(enable && !check_sameq.isSelected());
		spinner_vkbps.setEnabled(enable && !check_sameq.isSelected());
		check_redim.setEnabled(enable);
		Boolean b = radio_recvideo.isSelected() && check_redim.isSelected()
				&& combo_redim.getSelectedIndex() == 0;
		spinner_height.setEnabled(b);
		spinner_width.setEnabled(b);
	}

	/**
	 * Inserta los archivos arrastrados sobre la tabla en la lista de archivos a
	 * convertir.
	 */
	@Override
	public void addFilesToTable(File[] files) {
		boolean someone = false;
		for (File f : files) {
			if (conversion.isSupported(f)) {
				if (f.isFile() && conversion.addFile(f)) {
					someone = true;
				} else if (f.isDirectory()) {
					int sol = JOptionPane.showConfirmDialog(
							getComponent(),
							config.getLanguage().getValueOf(
									"dialog_recursive_prefix")
									+ "\n\""
									+ f.getAbsolutePath()
									+ "\"\n"
									+ config.getLanguage().getValueOf(
											"dialog_recursive_suffix"),
							config.getLanguage().getValueOf(
									"dialog_recursive_title"),
							JOptionPane.OK_CANCEL_OPTION,
							JOptionPane.QUESTION_MESSAGE);
					if (sol == JOptionPane.OK_OPTION) {
						addFilesToTable(f.listFiles());
					}
				}
			} else {
				YakiToOutput.error("El archivo \"" + f.getAbsolutePath()
						+ "\" no es un archivo multimedia soportado.");
				YakiToOutput.errorDialog(
						config.getLanguage().getValueOf(
								"dialog_file_not_supported_title"),
						config.getLanguage().getValueOf(
								"dialog_file_not_supported_prefix")
								+ " \n\""
								+ f.getAbsolutePath()
								+ "\"\n"
								+ config.getLanguage().getValueOf(
										"dialog_file_not_supported_suffix"));
			}
		}
		if (someone)
			updateTable();
	}

	private void enableAndDisableControls(boolean encoding) {
		this.button_start.setEnabled(!encoding);
		this.button_stop.setEnabled(encoding);
		this.button_add.setEnabled(!encoding);
		this.button_clear.setEnabled(!encoding);
		this.button_remove.setEnabled(!encoding);
		this.button_down.setEnabled(!encoding && !conversion.isConcurrent());
		this.button_up.setEnabled(!encoding && !conversion.isConcurrent());
		this.button_browse.setEnabled(!encoding);
		this.combo_profile.setEnabled(!encoding);
		this.menu_concurrent.setEnabled(!encoding);
		this.langMenu.setEnabled(!encoding);
		
	}

	private void setStatusToBusy() {

		this.statusMessageLabel.setText(config.getLanguage().getValueOf(
				"label_status_busy"));
		recoding = true;

		enableAndDisableControls(true);

		startStatusAnimation();
	}

	public void setStatusToIdle() {

		this.statusMessageLabel.setText(config.getLanguage().getValueOf(
				"label_status_idle"));
		recoding = false;

		enableAndDisableControls(false);

		stopStatusAnimation();
		this.setRemainingTime(0);
	}

	private void setStatusToPaused() {

		this.statusMessageLabel.setText(config.getLanguage().getValueOf(
				"label_status_paused"));

		pauseStatusAnimation();
	}

	private void clearList() {
		int sol = JOptionPane.showConfirmDialog(getComponent(), config
				.getLanguage().getValueOf("dialog_clearlist_text"), config
				.getLanguage().getValueOf("dialog_clearlist_title"),
				JOptionPane.OK_CANCEL_OPTION, JOptionPane.QUESTION_MESSAGE);
		if (sol == JOptionPane.OK_OPTION) {
			conversion.clearList();
			updateTable();
		}
	}

	/**
	 * Habilita el Drag and Drop de ficheros sobre la tabla de archivos a
	 * convertir.
	 */
	private void enableDragAndDrop() {
		final YakiToView mv = this;
		new FileDrop(System.out, this.jScrollPane1, this,
				new FileDrop.Listener() {
					public void filesDropped(java.io.File[] files) {
						mv.addFilesToTable(files);
					}
				});
	}

	/**
	 * Prepara la tabla con las columnas necesarias, y establece el nombre de
	 * las mismas a partir del idioma establecido. Despues rellena la tabla con
	 * los archivos a convertir.
	 */
	private void initTable() {		
		tableModel = new DefaultTableModel(){
			@Override
			public boolean isCellEditable(int row, int col){
				return false;
			}
		};
		String table_file = "table_file", table_size = "table_size", table_progress = "table_progress";
		if (config.getLanguage() != null) {
			table_file = config.getLanguage().getValueOf(table_file);
			table_size = config.getLanguage().getValueOf(table_size);
			table_progress = config.getLanguage().getValueOf(table_progress);
		}
		this.tableModel.addColumn(table_file);
		this.tableModel.addColumn(table_size);
		this.tableModel.addColumn(table_progress);
		table.setModel(tableModel);
		table.getColumnModel().getColumn(2)
				.setCellRenderer(new ProgressRenderer());
		YakiToRowRenderer rowRenderer = new YakiToRowRenderer(conversion);
		for (int j = 0; j < table.getColumnCount() - 1; j++)
			table.getColumnModel().getColumn(j).setCellRenderer(rowRenderer);
		table.getColumnModel().getColumn(table.getColumnCount() - 1)
				.setPreferredWidth(250);
		table.getColumnModel().getColumn(table.getColumnCount() - 1)
				.setMinWidth(250);
		table.getColumnModel().getColumn(0).setPreferredWidth(300);
		table.getColumnModel().getColumn(0).setMinWidth(300);
		
		// Activamos el "drag and drop" sobre la tabla de archivos
		enableDragAndDrop();
	}

	private void updateTable() {
		int n = table.getRowCount();
		for (int i = 0; i < n; i++)
			tableModel.removeRow(0);
		for (File f : conversion.getFiles()) {
			Object[] row = new Object[3];
			row[0] = f.getName();
			row[1] = Utils.sizeToString(f.length(), 2);
			row[2] = conversion.getBarOfFile(f);
			tableModel.addRow(row);
		}
		jLabel6.setText(conversion.getFiles().size() + " "
				+ config.getLanguage().getValueOf("label_files"));
	}

	/**
	 * Obtiene recursivamente todos los componentes visuales de la interfaz
	 * grafica, a partir de uno dado.
	 * 
	 * @param c
	 *            Componente padre
	 * @return Lista de componentes jerarquicamente inferiores a <code>c</code>
	 */
	public List<JComponent> getAllVisualComponents(JComponent c) {
		LinkedList<JComponent> list = new LinkedList<JComponent>();
		if (!list.contains(c))
			list.add(c);
		for (Component comp : c.getComponents()) {
			if (comp instanceof JComponent) {
				list.addAll(getAllVisualComponents((JComponent) comp));
			}
		}
		return list;
	}

	/**
	 * Refresca el idioma de la interfaz a partir del idioma establecido en el
	 * objeto de configuracion.
	 */
	public void updateLanguage() {

		// Obtenemos el idioma
		YakiToLanguage lang = config.getLanguage();

		// Actualizamos el icono de idioma de la barra de menu
		if (lang != null) {
			langMenu.setIcon(lang.getIcon());
			langMenu.setText("");

			// Elementos corrientes
			List<JComponent> componentes = getAllVisualComponents(this.mainPanel);
			componentes.addAll(this.getAllVisualComponents(this.menuBar));
			componentes.addAll(this.getAllVisualComponents(this.statusPanel));
			for (JComponent c : componentes) {
				String tag = c.getName();
				String tag2 = "tooltip_" + tag;
				if (tag != null) {
					String val = lang.getValueOf(tag);
					// System.out.println("val(" + tag + ") = " + val);
					String val2 = lang.getValueOf(tag2);
					if (val2 != null && val2.length() > 0
							&& !tag.startsWith("panel"))
						c.setToolTipText(val2);
					if (val != null && val.length() > 0) {
						if (tag.startsWith("button")) {
							((JButton) c).setText(val);
						} else if (tag.startsWith("label")) {
							((JLabel) c).setText(val);
						} else if (tag.startsWith("panel")) {
							((JPanel) c).setBorder(BorderFactory
									.createTitledBorder(val));
						} else if (tag.startsWith("radio")) {
							((JRadioButton) c).setText(val);
						} else if (tag.startsWith("check")) {
							((JCheckBox) c).setText(val);
						} else if (tag.startsWith("menu_")) {
							((JMenuItem) c).setText(val);
						} else if (tag.startsWith("textfield")) {
							((JTextField) c).setText(val);
						}
					}
				}

			}

			// Tabs
			tabs.setTitleAt(0, lang.getValueOf("tab_basic"));
			tabs.setToolTipTextAt(0, lang.getValueOf("tooltip_panel_basic"));
			tabs.setTitleAt(1, lang.getValueOf("tab_advanced"));
			tabs.setToolTipTextAt(1, lang.getValueOf("tooltip_panel_advanced"));

			// Elementos conflictivos
			// TODO: Integrar estas traducciones con la de elementos comunes
			String s = lang.getValueOf("menu_exit");
			if (s != null && s.length() > 0)
				menuBar.getMenu(0).getItem(0)
						.setText(lang.getValueOf("menu_exit"));
			s = lang.getValueOf("menu_about");
			if (s != null && s.length() > 0)
				menuBar.getMenu(2).getItem(0)
						.setText(lang.getValueOf("menu_about"));
			s = lang.getValueOf("menu_concurrent");
			if (s != null && s.length() > 0)
				menu_concurrent.setText(lang.getValueOf("menu_concurrent"));
			s = lang.getValueOf("volume_tooltip");
			if (s != null && s.length() > 0)
				slider_volume.setToolTipText(s);

			// Otros elementos TODO: Hacer que solo se refresque el primer
			// elemento, y no tenga que volver a cargar perfiles
			fillComboProfiles();
			fillComboRedim();

			/*
			 * // Barra de menu
			 * menuBar.getMenu(0).setText(lang.getValueOf("menu_file"));
			 * menuBar.
			 * getMenu(0).getItem(0).setText(lang.getValueOf("menu_exit"));
			 * menuBar.getMenu(2).setText(lang.getValueOf("menu_help"));
			 * menuBar.
			 * getMenu(2).getItem(0).setText(lang.getValueOf("menu_about"));
			 * menu_options.setText(lang.getValueOf("menu_options"));
			 * menu_concurrent.setText(lang.getValueOf("menu_concurrent"));
			 * 
			 * // Tab de conversion simple
			 * panel_destiny.setBorder(BorderFactory.createTitledBorder(lang
			 * .getValueOf("panel_destiny")));
			 * button_browse.setToolTipText(lang.getValueOf
			 * ("tooltip_button_browse"));
			 * panel_profile.setBorder(BorderFactory.createTitledBorder(lang
			 * .getValueOf("panel_profile")));
			 * combo_profile.setToolTipText(lang.getValueOf
			 * ("tooltip_combo_profile"));
			 * panel_table.setBorder(BorderFactory.createTitledBorder(lang
			 * .getValueOf("panel_table")));
			 * button_add.setToolTipText(lang.getValueOf("tooltip_button_add"));
			 * button_remove
			 * .setToolTipText(lang.getValueOf("tooltip_button_remove"));
			 * button_up.setToolTipText(lang.getValueOf("tooltip_button_up"));
			 * button_down
			 * .setToolTipText(lang.getValueOf("tooltip_button_down"));
			 * button_clear
			 * .setToolTipText(lang.getValueOf("tooltip_button_clear"));
			 * button_start.setText(lang.getValueOf("button_start"));
			 * button_start
			 * .setToolTipText(lang.getValueOf("tooltip_button_start"));
			 * button_stop.setText(lang.getValueOf("button_stop"));
			 * button_stop.setToolTipText
			 * (lang.getValueOf("tooltip_button_stop")); // Tab de conversion
			 * avanzada
			 * panel_container.setBorder(BorderFactory.createTitledBorder(lang
			 * .getValueOf("panel_container")));
			 * panel_saveprofile.setBorder(BorderFactory.createTitledBorder(lang
			 * .getValueOf("panel_saveprofile")));
			 * panel_audio.setBorder(BorderFactory.createTitledBorder(lang
			 * .getValueOf("panel_audio")));
			 * panel_video.setBorder(BorderFactory.createTitledBorder(lang
			 * .getValueOf("panel_video")));
			 * radio_recaudio.setText(lang.getValueOf("radio_recaudio"));
			 * radio_sameaudio.setText(lang.getValueOf("radio_sameaudio"));
			 * radio_noaudio.setText(lang.getValueOf("radio_noaudio"));
			 * label_acodec.setText(lang.getValueOf("label_acodec"));
			 * label_akbps.setText(lang.getValueOf("label_akbps"));
			 * label_afreq.setText(lang.getValueOf("label_afreq"));
			 * label_achannels.setText(lang.getValueOf("label_achannels"));
			 * label_volume.setText(lang.getValueOf("label_volume"));
			 * radio_recvideo.setText(lang.getValueOf("radio_recvideo"));
			 * radio_samevideo.setText(lang.getValueOf("radio_samevideo"));
			 * radio_novideo.setText(lang.getValueOf("radio_novideo"));
			 * check_sameq.setText(lang.getValueOf("check_sameq"));
			 * label_vcodec.setText(lang.getValueOf("label_vcodec"));
			 * label_vtag.setText(lang.getValueOf("label_vtag"));
			 * label_vkbps.setText(lang.getValueOf("label_vkbps"));
			 * check_redim.setText(lang.getValueOf("check_redim"));
			 * label_name.setText(lang.getValueOf("label_name"));
			 * button_saveprofile
			 * .setText(lang.getValueOf("button_saveprofile")); // Barra de
			 * estado
			 * label_completed.setText(lang.getValueOf("label_completed"));
			 * label_remaining.setText(lang.getValueOf("label_remaining"));
			 */

		}
		// Nombre de las columnas de la tabla
		initTable();
		updateTable();
		// Barra de estado
		setStatusToIdle();
	}

	/**
	 * Establece un nuevo idioma para esta y las futuras sesiones.
	 * 
	 * @param s
	 *            Nombre del idioma
	 */
	private void setLanguage(String s) throws YakiToNoLanguagesException {
		config.setLanguage(s);
		updateLanguage();
		/**
		 * JOptionPane p = new JOptionPane(); JOptionPane .showMessageDialog(
		 * this.getComponent(), "Se ha cambiado el idioma de la interfaz a " + s
		 * +
		 * ".\nAlgunos elementos no serán traducidos hasta que reinicie la YakiTo."
		 * );
		 */
	}

	/**
	 * Fills audio codecs ComboBox with all available audio codecs in the ffmpeg
	 * binary. Available audio codecs info is provided by YakiToCodec class.
	 */
	private void fillComboACodecs() {
		LinkedList<String> acodecs = YakiToCodec.listAvailableAudioCodecs();
		combo_acodec.removeAllItems();
		for (int i = 0; i < acodecs.size(); i++) {
			combo_acodec.addItem(acodecs.get(i));
		}
		// Set default audio codec as mp3
		String def = "libmp3lame";
		if (acodecs.contains(def))
			combo_acodec.setSelectedItem(def);
	}

	/**
	 * Fills video codecs ComboBox with all available audio codecs in the ffmpeg
	 * binary. Available audio codecs info is provided by YakiToCodec class.
	 */
	private void fillComboVCodecs() {
		LinkedList<String> vcodecs = YakiToCodec.listAvailableVideoCodecs();
		combo_vcodec.removeAllItems();
		for (int i = 0; i < vcodecs.size(); i++) {
			combo_vcodec.addItem(vcodecs.get(i));
		}
		String def = "mpeg4";
		if (vcodecs.contains(def))
			combo_vcodec.setSelectedItem(def);
	}

	/**
	 * Genera el menu de idiomas de la derecha, con todos los idiomas que se
	 * hayan encontrado disponibles al arrancar la aplicacion.
	 */
	private void genLangMenu() throws YakiToNoLanguagesException {
		List<YakiToLanguage> languages = config.getAvailableLanguages();
		// Menu de la derecha
		menuBar.add(Box.createHorizontalGlue());
		langMenu = new JMenu("lang");
		if (languages != null) {
			for (YakiToLanguage l : languages) {
				JMenuItem item = new JMenuItem(l.getName(), l.getIcon());
				item.addActionListener(new ActionListener() {
					public void actionPerformed(ActionEvent e) {
						try {
							setLanguage(((JMenuItem) e.getSource()).getText());
						} catch (YakiToNoLanguagesException e1) {
							// TODO Auto-generated catch block
							e1.printStackTrace();
						}
					}
				});
				langMenu.add(item);
			}
		}
		menuBar.add(langMenu);
	}

	private void up() {
		int[] selected = table.getSelectedRows();
		for (int i = 0; i < selected.length; i++) {
			boolean can = false;
			for (int j = 0; j < selected[i] && !can; j++) {
				if (!table.getSelectionModel().isSelectedIndex(j))
					can = true;
			}
			if (can) {
				File f = conversion.getFileAt(selected[i]);
				conversion.morePriority(f);
				selected[i] = conversion.getIndexOf(f);
			}
		}
		updateTable();
		selectRows(selected);
	}

	private void down() {
		int[] selected = table.getSelectedRows();
		for (int i = 0; i < selected.length; i++) {
			boolean can = false;
			for (int j = selected[i]; j < table.getRowCount() && !can; j++) {
				if (!table.getSelectionModel().isSelectedIndex(j))
					can = true;
			}
			if (can) {
				File f = conversion.getFileAt(selected[i]);
				conversion.lessPriority(f);
				selected[i] = conversion.getIndexOf(f);
			}
		}
		updateTable();
		selectRows(selected);
	}

	private void selectRows(int[] rows) {
		table.getSelectionModel().clearSelection();
		for (int i : rows) {
			table.getSelectionModel().addSelectionInterval(i, i);
		}
	}

	private void levelLog() {
		java.util.logging.Logger logger = java.util.logging.Logger
				.getLogger(org.jdesktop.application.SessionStorage.class
						.getName());
		logger.setLevel(java.util.logging.Level.OFF);
	}

	private void pruebas() {
		progressBar.setVisible(true);
		progressBar.setStringPainted(true);

		Thread hilo = new Thread() {

			@Override
			public void run() {
				int x = 0;
				while (x <= 100) {
					progressBar.setValue(x++);
					progressBar.setString("Progreso total: " + x + "%");
					try {
						Thread.sleep(500);
					} catch (InterruptedException ex) {
					}

				}
			}
		};
		hilo.start();
	}

	/**
	 * Muestra el dialogo "A cerca de..." con informacion sobre la aplicacion,
	 * la version, la web y el autor.
	 */
	@Action
	public void showAboutBox() {

		JFrame mainFrame = YakiToApp.getApplication().getMainFrame();
		aboutBox = new YakiToAboutBox(mainFrame);
		aboutBox.setLocationRelativeTo(mainFrame);
		aboutBox.setVisible(true);

	}

	/**
	 * Inicia la animacion de estado
	 */
	public void startStatusAnimation() {
		busyIconTimer.start();
	}

	public void pauseStatusAnimation() {
		busyIconTimer.stop();
	}

	/**
	 * Detiene la animacion de estado
	 */
	public void stopStatusAnimation() {
		busyIconTimer.stop();
		statusAnimationLabel.setIcon(idleIcon);
		// conversion.stopConversion();
	}

	/**
	 * Inicia o pausa el proceso de codificacion
	 */
	@Action
	public void encodeStartOrPause() {
		if (conversion.getFiles().size() > 0) {
			if (!recoding) {
				boolean convert = false;
				if (conversion.someConvertedPreviously()) {
					int sol = JOptionPane.showConfirmDialog(
							getComponent(),
							config.getLanguage().getValueOf(
									"dialog_start_prefix")
									+ "\n"
									+ config.getLanguage().getValueOf(
											"dialog_start_suffix"),
							config.getLanguage().getValueOf(
									"dialog_start_title"),
							JOptionPane.OK_CANCEL_OPTION,
							JOptionPane.QUESTION_MESSAGE);
					if (sol == JOptionPane.OK_OPTION) {
						convert = true;
					}
				} else {
					convert = true;
				}
				if (convert) {
					setStatusToBusy();
					recoding = true;
					paused = false;
					readEncodingParameters();					
					conversion.startConversion();
				}
			} else {
				setStatusToPaused();
				recoding = false;
				paused = true;
				conversion.pauseConversion();
			}
		} else {
			JOptionPane.showMessageDialog(this.getComponent(), config
					.getLanguage().getValueOf("dialog_add_files_prefix")
					+ "\n"
					+ config.getLanguage()
							.getValueOf("dialog_add_files_suffix"), config
					.getLanguage().getValueOf("dialog_add_files_title"),
					JOptionPane.WARNING_MESSAGE);
		}
	}

	/**
	 * Lee todos los parametros de conversion de la interfaz
	 */
	private void readEncodingParameters() {
		conversion.clean();
		conversion.setFormat(((YakiToContainer) combo_container
				.getSelectedItem()).getExtension());
		String ads = " ["
				+ ((combo_profile.getSelectedIndex() == 0) ? ("YakiTo")
						: (((YakiToProfile) combo_profile.getSelectedItem())
								.toString())) + "]";
		conversion.setAds(ads);
		String argstext = textfield_extra.getText();
		if (argstext != null && argstext.length() > 0) {
			String[] args = argstext.split(" ");
			for (String s : args) {
				conversion.addExtraArgum(s);
			}
		}
		// Parametros de audio
		if (this.radio_recaudio.isSelected()) {
			// Se recodifica el stream de audio
			conversion.setAmode(Mode.RECODE);
			conversion.setAchannels(combo_achannels.getSelectedIndex() + 1);
			conversion.setACodec((String) combo_acodec.getSelectedItem());
			conversion.setAfreq((Integer) combo_afreq.getSelectedItem());
			conversion.setVolume(slider_volume.getValue());
			conversion.setAkbps((Integer) spinner_akbps.getValue());
		} else if (radio_sameaudio.isSelected()) {
			// Se copia el stream de audio
			conversion.setAmode(Mode.COPY);
		} else {
			// Audio deshabilitado
			conversion.setAmode(Mode.DISABLED);
		}

		// Parametros de video
		if (radio_recvideo.isSelected()) {
			// Se recodifica el stream de video
			conversion.setVmode(Mode.RECODE);
			conversion.setVCodec((String) combo_vcodec.getSelectedItem());
			// Calidad de conversion
			if (check_sameq.isSelected()) {
				conversion.addExtraArgum("-sameq");
			} else {
				conversion.setVkbps((Integer) spinner_vkbps.getValue());
				conversion.setFps((Integer) spinner_fps.getValue());
			}
			String vtag = combo_vtag.getText();
			if (vtag != null && vtag.length() > 0)
				conversion.setVtag(vtag);
			conversion.setSameq(check_sameq.isSelected());
			if (check_redim.isSelected()) {
				if (combo_redim.getSelectedIndex() == 0) {
					// Redimensionado personalizado
					conversion.setRedimMode(Redim.CUSTOM);
					int[] size = new int[2];
					size[0] = (Integer) spinner_width.getValue();
					size[1] = (Integer) spinner_height.getValue();
					conversion.setSize(size);
				} else {
					// Otro redimensionado
					conversion.setRedimMode(Redim.OTHER);
					conversion.setRedim((String) combo_redim.getSelectedItem());
				}
			} else {
				conversion.setRedimMode(Redim.NO);
			}
		} else if (radio_samevideo.isSelected()) {
			// Se copia el stream de video
			conversion.setVmode(Mode.COPY);
		} else {
			// Video deshabilitado
			conversion.setVmode(Mode.DISABLED);
		}
	}

	/**
	 * Obtiene los parametros adicionales de conversion. Estos son introducidos
	 * por el usuario avanzado.
	 * 
	 * @return
	 */
	private String getExtraParams() {
		String s = "";
		s = textfield_extra.getText();
		return s;
	}

	/**
	 * Detiene el proceso de codificacion
	 */
	@Action
	public void encodeStop() {
		if (recoding || paused) {
			int sol = JOptionPane.showConfirmDialog(getComponent(), config
					.getLanguage().getValueOf("dialog_stop_prefix")
					+ "\n"
					+ config.getLanguage().getValueOf("dialog_stop_suffix"),
					config.getLanguage().getValueOf("dialog_stop_title"),
					JOptionPane.OK_CANCEL_OPTION, JOptionPane.QUESTION_MESSAGE);
			if (sol == JOptionPane.OK_OPTION) {
				recoding = false;
				paused = false;
				// setStatusToIdle();
				conversion.stopConversion();
			}
		}
	}

	private void removeSelectedFiles() {
		int[] selected = table.getSelectedRows();
		int sol = JOptionPane
				.showConfirmDialog(
						getComponent(),
						config.getLanguage().getValueOf(
								"dialog_remove_selected_prefix")
								+ " "
								+ selected.length
								+ " "
								+ config.getLanguage().getValueOf(
										"dialog_remove_selected_suffix"),
						config.getLanguage().getValueOf(
								"dialog_remove_selected_title"),
						JOptionPane.OK_CANCEL_OPTION,
						JOptionPane.QUESTION_MESSAGE);
		if (sol == JOptionPane.OK_OPTION) {
			File[] files = new File[selected.length];
			for (int i = 0; i < selected.length; i++) {
				files[i] = conversion.getFileAt(selected[i]);
			}
			for (File f : files) {
				conversion.removeFile(f);
			}
			updateTable();
		}

	}

	/**
	 * This method is called from within the constructor to initialize the form.
	 */
	@SuppressWarnings("unchecked")
	// <editor-fold defaultstate="collapsed"
	// <editor-fold defaultstate="collapsed"
	// <editor-fold defaultstate="collapsed"
	// <editor-fold defaultstate="collapsed"
	// <editor-fold defaultstate="collapsed"
	// <editor-fold defaultstate="collapsed"
	// <editor-fold defaultstate="collapsed"
	// <editor-fold defaultstate="collapsed"
	// <editor-fold defaultstate="collapsed"
	// <editor-fold defaultstate="collapsed"
	// <editor-fold defaultstate="collapsed"
	// <editor-fold defaultstate="collapsed"
	// <editor-fold defaultstate="collapsed"
	// <editor-fold defaultstate="collapsed"
	// <editor-fold defaultstate="collapsed"
	// <editor-fold defaultstate="collapsed"
    // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
    private void initComponents() {

        mainPanel = new javax.swing.JPanel();
        tabs = new javax.swing.JTabbedPane();
        panel_basic = new javax.swing.JPanel();
        panel_destiny = new javax.swing.JPanel();
        jTextField1 = new javax.swing.JTextField();
        button_browse = new javax.swing.JButton();
        panel_profile = new javax.swing.JPanel();
        combo_profile = new javax.swing.JComboBox();
        panel_table = new javax.swing.JPanel();
        jPanel6 = new javax.swing.JPanel();
        jScrollPane1 = new javax.swing.JScrollPane();
        table = new javax.swing.JTable();
        jPanel7 = new javax.swing.JPanel();
        button_add = new javax.swing.JButton();
        button_remove = new javax.swing.JButton();
        button_up = new javax.swing.JButton();
        button_down = new javax.swing.JButton();
        button_clear = new javax.swing.JButton();
        panel_advanced = new javax.swing.JPanel();
        splitPane_horizontal = new javax.swing.JSplitPane();
        panel_audio = new javax.swing.JPanel();
        radio_recaudio = new javax.swing.JRadioButton();
        radio_sameaudio = new javax.swing.JRadioButton();
        radio_noaudio = new javax.swing.JRadioButton();
        jSeparator4 = new javax.swing.JSeparator();
        label_acodec = new javax.swing.JLabel();
        combo_acodec = new javax.swing.JComboBox();
        label_akbps = new javax.swing.JLabel();
        spinner_akbps = new javax.swing.JSpinner();
        jLabel11 = new javax.swing.JLabel();
        label_afreq = new javax.swing.JLabel();
        combo_afreq = new javax.swing.JComboBox();
        jLabel13 = new javax.swing.JLabel();
        label_achannels = new javax.swing.JLabel();
        combo_achannels = new javax.swing.JComboBox();
        jSeparator6 = new javax.swing.JSeparator();
        label_volume = new javax.swing.JLabel();
        slider_volume = new javax.swing.JSlider();
        jLabel16 = new javax.swing.JLabel();
        jLabel17 = new javax.swing.JLabel();
        jPanel2 = new javax.swing.JPanel();
        panel_extra = new javax.swing.JPanel();
        textfield_extra = new javax.swing.JTextField();
        panel_video = new javax.swing.JPanel();
        radio_recvideo = new javax.swing.JRadioButton();
        radio_samevideo = new javax.swing.JRadioButton();
        radio_novideo = new javax.swing.JRadioButton();
        jSeparator5 = new javax.swing.JSeparator();
        check_sameq = new javax.swing.JCheckBox();
        label_vcodec = new javax.swing.JLabel();
        combo_vcodec = new javax.swing.JComboBox();
        label_vtag = new javax.swing.JLabel();
        combo_vtag = new javax.swing.JTextField();
        label_vkbps = new javax.swing.JLabel();
        spinner_vkbps = new javax.swing.JSpinner();
        jLabel22 = new javax.swing.JLabel();
        spinner_fps = new javax.swing.JSpinner();
        jSeparator7 = new javax.swing.JSeparator();
        check_redim = new javax.swing.JCheckBox();
        combo_redim = new javax.swing.JComboBox();
        spinner_height = new javax.swing.JSpinner();
        spinner_width = new javax.swing.JSpinner();
        jLabel23 = new javax.swing.JLabel();
        jLabel5 = new javax.swing.JLabel();
        panel_container = new javax.swing.JPanel();
        combo_container = new javax.swing.JComboBox();
        panel_saveprofile = new javax.swing.JPanel();
        label_name = new javax.swing.JLabel();
        textfield_name = new javax.swing.JTextField();
        button_saveprofile = new javax.swing.JButton();
        panel_buttons = new javax.swing.JPanel();
        button_start = new javax.swing.JButton();
        button_stop = new javax.swing.JButton();
        jSeparator1 = new javax.swing.JSeparator();
        progressBar = new javax.swing.JProgressBar();
        jLabel6 = new javax.swing.JLabel();
        menuBar = new javax.swing.JMenuBar();
        javax.swing.JMenu menu_file = new javax.swing.JMenu();
        javax.swing.JMenuItem exitMenuItem = new javax.swing.JMenuItem();
        menu_options = new javax.swing.JMenu();
        menu_concurrent = new javax.swing.JCheckBoxMenuItem();
        javax.swing.JMenu menu_help = new javax.swing.JMenu();
        javax.swing.JMenuItem menu_about = new javax.swing.JMenuItem();
        statusPanel = new javax.swing.JPanel();
        javax.swing.JSeparator statusPanelSeparator = new javax.swing.JSeparator();
        statusMessageLabel = new javax.swing.JLabel();
        statusAnimationLabel = new javax.swing.JLabel();
        label_ram = new javax.swing.JLabel();
        jSeparator2 = new javax.swing.JSeparator();
        label_time = new javax.swing.JLabel();
        label_remaining = new javax.swing.JLabel();
        label_percent = new javax.swing.JLabel();
        label_completed = new javax.swing.JLabel();
        jSeparator3 = new javax.swing.JSeparator();
        buttonGroup1 = new javax.swing.ButtonGroup();
        buttonGroup2 = new javax.swing.ButtonGroup();

        mainPanel.setName("mainPanel"); // NOI18N
        mainPanel.addComponentListener(new java.awt.event.ComponentAdapter() {
            public void componentResized(java.awt.event.ComponentEvent evt) {
                mainPanelComponentResized(evt);
            }
        });

        tabs.setName("tabs"); // NOI18N

        panel_basic.setName("panel_basic"); // NOI18N

        org.jdesktop.application.ResourceMap resourceMap = org.jdesktop.application.Application.getInstance(net.yakiboo.yakito.YakiToApp.class).getContext().getResourceMap(YakiToView.class);
        panel_destiny.setBorder(javax.swing.BorderFactory.createTitledBorder(null, resourceMap.getString("panel_destiny.border.title"), javax.swing.border.TitledBorder.LEFT, javax.swing.border.TitledBorder.DEFAULT_POSITION)); // NOI18N
        panel_destiny.setName("panel_destiny"); // NOI18N

        jTextField1.setEditable(false);
        jTextField1.setText(resourceMap.getString("textfield_destiny.text")); // NOI18N
        jTextField1.setName("textfield_destiny"); // NOI18N

        button_browse.setIcon(resourceMap.getIcon("button_browse.icon")); // NOI18N
        button_browse.setText(resourceMap.getString("button_browse.text")); // NOI18N
        button_browse.setName("button_browse"); // NOI18N
        button_browse.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                button_browseActionPerformed(evt);
            }
        });

        javax.swing.GroupLayout panel_destinyLayout = new javax.swing.GroupLayout(panel_destiny);
        panel_destiny.setLayout(panel_destinyLayout);
        panel_destinyLayout.setHorizontalGroup(
            panel_destinyLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, panel_destinyLayout.createSequentialGroup()
                .addContainerGap()
                .addComponent(jTextField1, javax.swing.GroupLayout.DEFAULT_SIZE, 391, Short.MAX_VALUE)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(button_browse)
                .addContainerGap())
        );
        panel_destinyLayout.setVerticalGroup(
            panel_destinyLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(panel_destinyLayout.createSequentialGroup()
                .addGroup(panel_destinyLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(jTextField1, javax.swing.GroupLayout.PREFERRED_SIZE, 28, javax.swing.GroupLayout.PREFERRED_SIZE)
                    .addComponent(button_browse))
                .addContainerGap(javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
        );

        panel_profile.setBorder(javax.swing.BorderFactory.createTitledBorder(null, resourceMap.getString("panel_profile.border.title"), javax.swing.border.TitledBorder.LEFT, javax.swing.border.TitledBorder.DEFAULT_POSITION)); // NOI18N
        panel_profile.setName("panel_profile"); // NOI18N

        combo_profile.setModel(new javax.swing.DefaultComboBoxModel(new String[] { "Item 1", "Item 2", "Item 3", "Item 4" }));
        combo_profile.setName("combo_profile"); // NOI18N
        combo_profile.addItemListener(new java.awt.event.ItemListener() {
            public void itemStateChanged(java.awt.event.ItemEvent evt) {
                combo_profileItemStateChanged(evt);
            }
        });
        combo_profile.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                combo_profileActionPerformed(evt);
            }
        });
        combo_profile.addPropertyChangeListener(new java.beans.PropertyChangeListener() {
            public void propertyChange(java.beans.PropertyChangeEvent evt) {
                combo_profilePropertyChange(evt);
            }
        });

        javax.swing.GroupLayout panel_profileLayout = new javax.swing.GroupLayout(panel_profile);
        panel_profile.setLayout(panel_profileLayout);
        panel_profileLayout.setHorizontalGroup(
            panel_profileLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(panel_profileLayout.createSequentialGroup()
                .addContainerGap()
                .addComponent(combo_profile, 0, 380, Short.MAX_VALUE)
                .addContainerGap())
        );
        panel_profileLayout.setVerticalGroup(
            panel_profileLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(panel_profileLayout.createSequentialGroup()
                .addComponent(combo_profile, javax.swing.GroupLayout.DEFAULT_SIZE, 28, Short.MAX_VALUE)
                .addContainerGap())
        );

        panel_table.setBorder(javax.swing.BorderFactory.createTitledBorder(resourceMap.getString("panel_table.border.title"))); // NOI18N
        panel_table.setName("panel_table"); // NOI18N

        jPanel6.setName("jPanel6"); // NOI18N

        jScrollPane1.setName("jScrollPane1"); // NOI18N

        table.setModel(new javax.swing.table.DefaultTableModel(
            new Object [][] {
                {null, null},
                {null, null},
                {null, null},
                {null, null}
            },
            new String [] {
                "Column1", "Column2"
            }
        ) {
            Class[] types = new Class [] {
                java.lang.String.class, java.lang.String.class
            };
            boolean[] canEdit = new boolean [] {
                false, false
            };

            public Class getColumnClass(int columnIndex) {
                return types [columnIndex];
            }

            public boolean isCellEditable(int rowIndex, int columnIndex) {
                return canEdit [columnIndex];
            }
        });
        table.setName("table"); // NOI18N
        jScrollPane1.setViewportView(table);
        table.getColumnModel().getColumn(0).setHeaderValue(resourceMap.getString("table.columnModel.title0")); // NOI18N
        table.getColumnModel().getColumn(1).setHeaderValue(resourceMap.getString("table.columnModel.title1")); // NOI18N

        javax.swing.GroupLayout jPanel6Layout = new javax.swing.GroupLayout(jPanel6);
        jPanel6.setLayout(jPanel6Layout);
        jPanel6Layout.setHorizontalGroup(
            jPanel6Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(jPanel6Layout.createSequentialGroup()
                .addContainerGap()
                .addComponent(jScrollPane1, javax.swing.GroupLayout.DEFAULT_SIZE, 801, Short.MAX_VALUE))
        );
        jPanel6Layout.setVerticalGroup(
            jPanel6Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(jPanel6Layout.createSequentialGroup()
                .addComponent(jScrollPane1, javax.swing.GroupLayout.DEFAULT_SIZE, 413, Short.MAX_VALUE)
                .addContainerGap())
        );

        jPanel7.setName("jPanel7"); // NOI18N

        button_add.setIcon(resourceMap.getIcon("button_add.icon")); // NOI18N
        button_add.setText(resourceMap.getString("button_add.text")); // NOI18N
        button_add.setName("button_add"); // NOI18N
        button_add.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                button_addActionPerformed(evt);
            }
        });

        button_remove.setIcon(resourceMap.getIcon("button_remove.icon")); // NOI18N
        button_remove.setName("button_remove"); // NOI18N
        button_remove.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                button_removeActionPerformed(evt);
            }
        });

        button_up.setIcon(resourceMap.getIcon("button_up.icon")); // NOI18N
        button_up.setName("button_up"); // NOI18N
        button_up.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                button_upActionPerformed(evt);
            }
        });

        button_down.setIcon(resourceMap.getIcon("button_down.icon")); // NOI18N
        button_down.setName("button_down"); // NOI18N
        button_down.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                button_downActionPerformed(evt);
            }
        });

        button_clear.setIcon(resourceMap.getIcon("button_clear.icon")); // NOI18N
        button_clear.setName("button_clear"); // NOI18N
        button_clear.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                button_clearActionPerformed(evt);
            }
        });

        javax.swing.GroupLayout jPanel7Layout = new javax.swing.GroupLayout(jPanel7);
        jPanel7.setLayout(jPanel7Layout);
        jPanel7Layout.setHorizontalGroup(
            jPanel7Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(jPanel7Layout.createSequentialGroup()
                .addContainerGap(javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                .addGroup(jPanel7Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addComponent(button_clear, javax.swing.GroupLayout.Alignment.TRAILING)
                    .addComponent(button_add, javax.swing.GroupLayout.Alignment.TRAILING)
                    .addComponent(button_remove, javax.swing.GroupLayout.Alignment.TRAILING)
                    .addComponent(button_up, javax.swing.GroupLayout.Alignment.TRAILING)
                    .addComponent(button_down, javax.swing.GroupLayout.Alignment.TRAILING))
                .addContainerGap())
        );
        jPanel7Layout.setVerticalGroup(
            jPanel7Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(jPanel7Layout.createSequentialGroup()
                .addComponent(button_add)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(button_remove)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(button_up)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(button_down)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED, 255, Short.MAX_VALUE)
                .addComponent(button_clear)
                .addContainerGap())
        );

        javax.swing.GroupLayout panel_tableLayout = new javax.swing.GroupLayout(panel_table);
        panel_table.setLayout(panel_tableLayout);
        panel_tableLayout.setHorizontalGroup(
            panel_tableLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, panel_tableLayout.createSequentialGroup()
                .addComponent(jPanel6, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(jPanel7, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
        );
        panel_tableLayout.setVerticalGroup(
            panel_tableLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addComponent(jPanel7, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
            .addComponent(jPanel6, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
        );

        javax.swing.GroupLayout panel_basicLayout = new javax.swing.GroupLayout(panel_basic);
        panel_basic.setLayout(panel_basicLayout);
        panel_basicLayout.setHorizontalGroup(
            panel_basicLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(panel_basicLayout.createSequentialGroup()
                .addContainerGap()
                .addGroup(panel_basicLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addComponent(panel_table, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                    .addGroup(panel_basicLayout.createSequentialGroup()
                        .addComponent(panel_destiny, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addComponent(panel_profile, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)))
                .addContainerGap())
        );
        panel_basicLayout.setVerticalGroup(
            panel_basicLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(panel_basicLayout.createSequentialGroup()
                .addContainerGap()
                .addGroup(panel_basicLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addComponent(panel_profile, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                    .addComponent(panel_destiny, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(panel_table, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                .addContainerGap())
        );

        tabs.addTab(resourceMap.getString("panel_basic.TabConstraints.tabTitle"), resourceMap.getIcon("panel_basic.TabConstraints.tabIcon"), panel_basic); // NOI18N

        panel_advanced.setName("panel_advanced"); // NOI18N

        splitPane_horizontal.setDividerLocation(420);
        splitPane_horizontal.setDividerSize(5);
        splitPane_horizontal.setName("splitPane_horizontal"); // NOI18N

        panel_audio.setBorder(javax.swing.BorderFactory.createTitledBorder(resourceMap.getString("panel_audio.border.title"))); // NOI18N
        panel_audio.setName("panel_audio"); // NOI18N

        buttonGroup2.add(radio_recaudio);
        radio_recaudio.setSelected(true);
        radio_recaudio.setText(resourceMap.getString("radio_recaudio.text")); // NOI18N
        radio_recaudio.setName("radio_recaudio"); // NOI18N
        radio_recaudio.addItemListener(new java.awt.event.ItemListener() {
            public void itemStateChanged(java.awt.event.ItemEvent evt) {
                radio_recaudioItemStateChanged(evt);
            }
        });

        buttonGroup2.add(radio_sameaudio);
        radio_sameaudio.setText(resourceMap.getString("radio_sameaudio.text")); // NOI18N
        radio_sameaudio.setName("radio_sameaudio"); // NOI18N
        radio_sameaudio.addItemListener(new java.awt.event.ItemListener() {
            public void itemStateChanged(java.awt.event.ItemEvent evt) {
                radio_sameaudioItemStateChanged(evt);
            }
        });

        buttonGroup2.add(radio_noaudio);
        radio_noaudio.setText(resourceMap.getString("radio_noaudio.text")); // NOI18N
        radio_noaudio.setName("radio_noaudio"); // NOI18N
        radio_noaudio.addItemListener(new java.awt.event.ItemListener() {
            public void itemStateChanged(java.awt.event.ItemEvent evt) {
                radio_noaudioItemStateChanged(evt);
            }
        });

        jSeparator4.setName("jSeparator4"); // NOI18N

        label_acodec.setText(resourceMap.getString("label_acodec.text")); // NOI18N
        label_acodec.setName("label_acodec"); // NOI18N

        combo_acodec.setModel(new javax.swing.DefaultComboBoxModel(new String[] { "Item 1", "Item 2", "Item 3", "Item 4" }));
        combo_acodec.setName("combo_acodec"); // NOI18N

        label_akbps.setText(resourceMap.getString("label_akbps.text")); // NOI18N
        label_akbps.setName("label_akbps"); // NOI18N

        spinner_akbps.setModel(new javax.swing.SpinnerNumberModel(128, 32, 5644, 1));
        spinner_akbps.setName("spinner_akbps"); // NOI18N

        jLabel11.setText(resourceMap.getString("jLabel11.text")); // NOI18N
        jLabel11.setName("jLabel11"); // NOI18N

        label_afreq.setText(resourceMap.getString("label_afreq.text")); // NOI18N
        label_afreq.setName("label_afreq"); // NOI18N

        combo_afreq.setModel(new javax.swing.DefaultComboBoxModel(new String[] { "Item 1", "Item 2", "Item 3", "Item 4" }));
        combo_afreq.setName("combo_afreq"); // NOI18N

        jLabel13.setText(resourceMap.getString("jLabel13.text")); // NOI18N
        jLabel13.setName("jLabel13"); // NOI18N

        label_achannels.setText(resourceMap.getString("label_achannels.text")); // NOI18N
        label_achannels.setName("label_achannels"); // NOI18N

        combo_achannels.setModel(new javax.swing.DefaultComboBoxModel(new String[] { "Item 1", "Item 2", "Item 3", "Item 4" }));
        combo_achannels.setName("combo_achannels"); // NOI18N

        jSeparator6.setName("jSeparator6"); // NOI18N

        label_volume.setText(resourceMap.getString("label_volume.text")); // NOI18N
        label_volume.setName("label_volume"); // NOI18N

        slider_volume.setMinimum(-100);
        slider_volume.setValue(0);
        slider_volume.setName("slider_volume"); // NOI18N

        jLabel16.setIcon(resourceMap.getIcon("jLabel16.icon")); // NOI18N
        jLabel16.setText(resourceMap.getString("jLabel16.text")); // NOI18N
        jLabel16.setName("jLabel16"); // NOI18N

        jLabel17.setIcon(resourceMap.getIcon("jLabel17.icon")); // NOI18N
        jLabel17.setText(resourceMap.getString("jLabel17.text")); // NOI18N
        jLabel17.setName("jLabel17"); // NOI18N

        javax.swing.GroupLayout panel_audioLayout = new javax.swing.GroupLayout(panel_audio);
        panel_audio.setLayout(panel_audioLayout);
        panel_audioLayout.setHorizontalGroup(
            panel_audioLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(panel_audioLayout.createSequentialGroup()
                .addContainerGap()
                .addGroup(panel_audioLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addComponent(jSeparator6, javax.swing.GroupLayout.DEFAULT_SIZE, 384, Short.MAX_VALUE)
                    .addComponent(jSeparator4, javax.swing.GroupLayout.DEFAULT_SIZE, 384, Short.MAX_VALUE)
                    .addComponent(radio_recaudio)
                    .addComponent(radio_sameaudio)
                    .addComponent(radio_noaudio)
                    .addGroup(panel_audioLayout.createSequentialGroup()
                        .addComponent(label_acodec)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addComponent(combo_acodec, 0, 280, Short.MAX_VALUE))
                    .addGroup(panel_audioLayout.createSequentialGroup()
                        .addComponent(label_akbps)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addComponent(spinner_akbps, javax.swing.GroupLayout.DEFAULT_SIZE, 246, Short.MAX_VALUE)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addComponent(jLabel11))
                    .addGroup(panel_audioLayout.createSequentialGroup()
                        .addComponent(label_afreq)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addComponent(combo_afreq, 0, 250, Short.MAX_VALUE)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addComponent(jLabel13))
                    .addGroup(panel_audioLayout.createSequentialGroup()
                        .addComponent(label_achannels)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addComponent(combo_achannels, 0, 260, Short.MAX_VALUE))
                    .addComponent(label_volume)
                    .addGroup(panel_audioLayout.createSequentialGroup()
                        .addComponent(jLabel16)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addComponent(slider_volume, javax.swing.GroupLayout.DEFAULT_SIZE, 328, Short.MAX_VALUE)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addComponent(jLabel17)))
                .addContainerGap())
        );
        panel_audioLayout.setVerticalGroup(
            panel_audioLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(panel_audioLayout.createSequentialGroup()
                .addComponent(radio_recaudio)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(radio_sameaudio)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(radio_noaudio)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(jSeparator4, javax.swing.GroupLayout.PREFERRED_SIZE, 10, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addGroup(panel_audioLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(label_acodec)
                    .addComponent(combo_acodec, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addGroup(panel_audioLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(label_akbps)
                    .addComponent(spinner_akbps, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                    .addComponent(jLabel11))
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addGroup(panel_audioLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(label_afreq)
                    .addComponent(combo_afreq, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                    .addComponent(jLabel13))
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addGroup(panel_audioLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(label_achannels)
                    .addComponent(combo_achannels, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(jSeparator6, javax.swing.GroupLayout.PREFERRED_SIZE, 10, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(label_volume)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addGroup(panel_audioLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING, false)
                    .addComponent(jLabel17, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                    .addComponent(slider_volume, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                    .addComponent(jLabel16, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
                .addContainerGap(89, Short.MAX_VALUE))
        );

        splitPane_horizontal.setLeftComponent(panel_audio);

        jPanel2.setName("jPanel2"); // NOI18N

        panel_extra.setBorder(javax.swing.BorderFactory.createTitledBorder(resourceMap.getString("panel_extra.border.title"))); // NOI18N
        panel_extra.setName("panel_extra"); // NOI18N

        textfield_extra.setText(resourceMap.getString("textfield_extra.text")); // NOI18N
        textfield_extra.setName("textfield_extra"); // NOI18N

        javax.swing.GroupLayout panel_extraLayout = new javax.swing.GroupLayout(panel_extra);
        panel_extra.setLayout(panel_extraLayout);
        panel_extraLayout.setHorizontalGroup(
            panel_extraLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(panel_extraLayout.createSequentialGroup()
                .addContainerGap()
                .addComponent(textfield_extra, javax.swing.GroupLayout.DEFAULT_SIZE, 422, Short.MAX_VALUE)
                .addContainerGap())
        );
        panel_extraLayout.setVerticalGroup(
            panel_extraLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, panel_extraLayout.createSequentialGroup()
                .addContainerGap(javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                .addComponent(textfield_extra, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addContainerGap())
        );

        panel_video.setBorder(javax.swing.BorderFactory.createTitledBorder(resourceMap.getString("panel_video.border.title"))); // NOI18N
        panel_video.setName("panel_video"); // NOI18N

        buttonGroup1.add(radio_recvideo);
        radio_recvideo.setSelected(true);
        radio_recvideo.setText(resourceMap.getString("radio_recvideo.text")); // NOI18N
        radio_recvideo.setName("radio_recvideo"); // NOI18N
        radio_recvideo.addItemListener(new java.awt.event.ItemListener() {
            public void itemStateChanged(java.awt.event.ItemEvent evt) {
                radio_recvideoItemStateChanged(evt);
            }
        });

        buttonGroup1.add(radio_samevideo);
        radio_samevideo.setText(resourceMap.getString("radio_samevideo.text")); // NOI18N
        radio_samevideo.setName("radio_samevideo"); // NOI18N
        radio_samevideo.addItemListener(new java.awt.event.ItemListener() {
            public void itemStateChanged(java.awt.event.ItemEvent evt) {
                radio_samevideoItemStateChanged(evt);
            }
        });

        buttonGroup1.add(radio_novideo);
        radio_novideo.setText(resourceMap.getString("radio_novideo.text")); // NOI18N
        radio_novideo.setName("radio_novideo"); // NOI18N
        radio_novideo.addItemListener(new java.awt.event.ItemListener() {
            public void itemStateChanged(java.awt.event.ItemEvent evt) {
                radio_novideoItemStateChanged(evt);
            }
        });

        jSeparator5.setName("jSeparator5"); // NOI18N

        check_sameq.setSelected(true);
        check_sameq.setText(resourceMap.getString("check_sameq.text")); // NOI18N
        check_sameq.setName("check_sameq"); // NOI18N
        check_sameq.addItemListener(new java.awt.event.ItemListener() {
            public void itemStateChanged(java.awt.event.ItemEvent evt) {
                check_sameqItemStateChanged(evt);
            }
        });

        label_vcodec.setText(resourceMap.getString("label_vcodec.text")); // NOI18N
        label_vcodec.setName("label_vcodec"); // NOI18N

        combo_vcodec.setModel(new javax.swing.DefaultComboBoxModel(new String[] { "Item 1", "Item 2", "Item 3", "Item 4" }));
        combo_vcodec.setName("combo_vcodec"); // NOI18N

        label_vtag.setText(resourceMap.getString("label_vtag.text")); // NOI18N
        label_vtag.setName("label_vtag"); // NOI18N

        combo_vtag.setText(resourceMap.getString("combo_vtag.text")); // NOI18N
        combo_vtag.setName("combo_vtag"); // NOI18N

        label_vkbps.setText(resourceMap.getString("label_vkbps.text")); // NOI18N
        label_vkbps.setName("label_vkbps"); // NOI18N

        spinner_vkbps.setModel(new javax.swing.SpinnerNumberModel(1000, 16, 40000, 1));
        spinner_vkbps.setEnabled(false);
        spinner_vkbps.setName("spinner_vkbps"); // NOI18N

        jLabel22.setText(resourceMap.getString("jLabel22.text")); // NOI18N
        jLabel22.setName("jLabel22"); // NOI18N

        spinner_fps.setModel(new javax.swing.SpinnerNumberModel(25, 5, 35, 1));
        spinner_fps.setEnabled(false);
        spinner_fps.setName("spinner_fps"); // NOI18N

        jSeparator7.setName("jSeparator7"); // NOI18N

        check_redim.setText(resourceMap.getString("check_redim.text")); // NOI18N
        check_redim.setName("check_redim"); // NOI18N
        check_redim.addItemListener(new java.awt.event.ItemListener() {
            public void itemStateChanged(java.awt.event.ItemEvent evt) {
                check_redimItemStateChanged(evt);
            }
        });

        combo_redim.setModel(new javax.swing.DefaultComboBoxModel(new String[] { "Item 1", "Item 2", "Item 3", "Item 4" }));
        combo_redim.setEnabled(false);
        combo_redim.setName("combo_redim"); // NOI18N
        combo_redim.addItemListener(new java.awt.event.ItemListener() {
            public void itemStateChanged(java.awt.event.ItemEvent evt) {
                combo_redimItemStateChanged(evt);
            }
        });

        spinner_height.setModel(new javax.swing.SpinnerNumberModel(1050, 50, 2000, 1));
        spinner_height.setEnabled(false);
        spinner_height.setName("spinner_height"); // NOI18N

        spinner_width.setModel(new javax.swing.SpinnerNumberModel(1050, 50, 2000, 1));
        spinner_width.setEnabled(false);
        spinner_width.setName("spinner_width"); // NOI18N

        jLabel23.setText(resourceMap.getString("jLabel23.text")); // NOI18N
        jLabel23.setName("jLabel23"); // NOI18N

        jLabel5.setText(resourceMap.getString("jLabel5.text")); // NOI18N
        jLabel5.setName("jLabel5"); // NOI18N

        javax.swing.GroupLayout panel_videoLayout = new javax.swing.GroupLayout(panel_video);
        panel_video.setLayout(panel_videoLayout);
        panel_videoLayout.setHorizontalGroup(
            panel_videoLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(panel_videoLayout.createSequentialGroup()
                .addContainerGap()
                .addGroup(panel_videoLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addComponent(jSeparator7, javax.swing.GroupLayout.DEFAULT_SIZE, 422, Short.MAX_VALUE)
                    .addComponent(jSeparator5, javax.swing.GroupLayout.DEFAULT_SIZE, 422, Short.MAX_VALUE)
                    .addGroup(panel_videoLayout.createSequentialGroup()
                        .addComponent(radio_recvideo)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED, 173, Short.MAX_VALUE)
                        .addComponent(check_sameq))
                    .addComponent(radio_samevideo)
                    .addComponent(radio_novideo)
                    .addGroup(panel_videoLayout.createSequentialGroup()
                        .addComponent(label_vcodec)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addComponent(combo_vcodec, 0, 319, Short.MAX_VALUE))
                    .addGroup(panel_videoLayout.createSequentialGroup()
                        .addComponent(label_vtag)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addComponent(combo_vtag, javax.swing.GroupLayout.DEFAULT_SIZE, 339, Short.MAX_VALUE))
                    .addGroup(panel_videoLayout.createSequentialGroup()
                        .addComponent(label_vkbps)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addComponent(spinner_vkbps, javax.swing.GroupLayout.DEFAULT_SIZE, 169, Short.MAX_VALUE)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addComponent(jLabel5)
                        .addGap(18, 18, 18)
                        .addComponent(jLabel22)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addComponent(spinner_fps, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                    .addGroup(panel_videoLayout.createSequentialGroup()
                        .addComponent(check_redim)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.UNRELATED)
                        .addComponent(combo_redim, 0, 295, Short.MAX_VALUE))
                    .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, panel_videoLayout.createSequentialGroup()
                        .addComponent(spinner_width, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addComponent(jLabel23)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addComponent(spinner_height, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)))
                .addContainerGap())
        );
        panel_videoLayout.setVerticalGroup(
            panel_videoLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(panel_videoLayout.createSequentialGroup()
                .addGroup(panel_videoLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(radio_recvideo)
                    .addComponent(check_sameq))
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(radio_samevideo)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(radio_novideo)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(jSeparator5, javax.swing.GroupLayout.PREFERRED_SIZE, 10, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addGroup(panel_videoLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(label_vcodec)
                    .addComponent(combo_vcodec, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addGroup(panel_videoLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(label_vtag)
                    .addComponent(combo_vtag, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addGroup(panel_videoLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(label_vkbps)
                    .addComponent(spinner_vkbps, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                    .addComponent(spinner_fps, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                    .addComponent(jLabel22)
                    .addComponent(jLabel5))
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(jSeparator7, javax.swing.GroupLayout.PREFERRED_SIZE, 10, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addGroup(panel_videoLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(check_redim)
                    .addComponent(combo_redim, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addGroup(panel_videoLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(spinner_height, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                    .addComponent(jLabel23)
                    .addComponent(spinner_width, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                .addContainerGap(54, Short.MAX_VALUE))
        );

        javax.swing.GroupLayout jPanel2Layout = new javax.swing.GroupLayout(jPanel2);
        jPanel2.setLayout(jPanel2Layout);
        jPanel2Layout.setHorizontalGroup(
            jPanel2Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addComponent(panel_extra, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
            .addComponent(panel_video, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
        );
        jPanel2Layout.setVerticalGroup(
            jPanel2Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, jPanel2Layout.createSequentialGroup()
                .addComponent(panel_video, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(panel_extra, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
        );

        splitPane_horizontal.setRightComponent(jPanel2);

        panel_container.setBorder(javax.swing.BorderFactory.createTitledBorder(resourceMap.getString("panel_container.border.title"))); // NOI18N
        panel_container.setName("panel_container"); // NOI18N

        combo_container.setModel(new javax.swing.DefaultComboBoxModel(new String[] { "Item 1", "Item 2", "Item 3", "Item 4" }));
        combo_container.setName("combo_container"); // NOI18N

        javax.swing.GroupLayout panel_containerLayout = new javax.swing.GroupLayout(panel_container);
        panel_container.setLayout(panel_containerLayout);
        panel_containerLayout.setHorizontalGroup(
            panel_containerLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(panel_containerLayout.createSequentialGroup()
                .addContainerGap()
                .addComponent(combo_container, 0, 345, Short.MAX_VALUE)
                .addContainerGap())
        );
        panel_containerLayout.setVerticalGroup(
            panel_containerLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(panel_containerLayout.createSequentialGroup()
                .addComponent(combo_container, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addContainerGap(javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
        );

        panel_saveprofile.setBorder(javax.swing.BorderFactory.createTitledBorder(resourceMap.getString("panel_saveprofile.border.title"))); // NOI18N
        panel_saveprofile.setName("panel_saveprofile"); // NOI18N

        label_name.setText(resourceMap.getString("label_name.text")); // NOI18N
        label_name.setName("label_name"); // NOI18N

        textfield_name.setText(resourceMap.getString("textfield_name.text")); // NOI18N
        textfield_name.setName("textfield_name"); // NOI18N

        button_saveprofile.setText(resourceMap.getString("button_saveprofile.text")); // NOI18N
        button_saveprofile.setName("button_saveprofile"); // NOI18N
        button_saveprofile.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                button_saveprofileActionPerformed(evt);
            }
        });

        javax.swing.GroupLayout panel_saveprofileLayout = new javax.swing.GroupLayout(panel_saveprofile);
        panel_saveprofile.setLayout(panel_saveprofileLayout);
        panel_saveprofileLayout.setHorizontalGroup(
            panel_saveprofileLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(panel_saveprofileLayout.createSequentialGroup()
                .addContainerGap()
                .addComponent(label_name)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(textfield_name, javax.swing.GroupLayout.DEFAULT_SIZE, 212, Short.MAX_VALUE)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.UNRELATED)
                .addComponent(button_saveprofile)
                .addContainerGap())
        );
        panel_saveprofileLayout.setVerticalGroup(
            panel_saveprofileLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(panel_saveprofileLayout.createSequentialGroup()
                .addGroup(panel_saveprofileLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(label_name)
                    .addComponent(textfield_name, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                    .addComponent(button_saveprofile))
                .addContainerGap(javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
        );

        javax.swing.GroupLayout panel_advancedLayout = new javax.swing.GroupLayout(panel_advanced);
        panel_advanced.setLayout(panel_advancedLayout);
        panel_advancedLayout.setHorizontalGroup(
            panel_advancedLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(panel_advancedLayout.createSequentialGroup()
                .addContainerGap()
                .addGroup(panel_advancedLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addComponent(splitPane_horizontal, javax.swing.GroupLayout.Alignment.TRAILING, javax.swing.GroupLayout.DEFAULT_SIZE, 883, Short.MAX_VALUE)
                    .addGroup(panel_advancedLayout.createSequentialGroup()
                        .addComponent(panel_container, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addComponent(panel_saveprofile, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)))
                .addContainerGap())
        );
        panel_advancedLayout.setVerticalGroup(
            panel_advancedLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(panel_advancedLayout.createSequentialGroup()
                .addContainerGap()
                .addGroup(panel_advancedLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING, false)
                    .addComponent(panel_container, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                    .addComponent(panel_saveprofile, javax.swing.GroupLayout.DEFAULT_SIZE, 67, Short.MAX_VALUE))
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(splitPane_horizontal, javax.swing.GroupLayout.DEFAULT_SIZE, 452, Short.MAX_VALUE)
                .addContainerGap())
        );

        tabs.addTab(resourceMap.getString("panel_advanced.TabConstraints.tabTitle"), resourceMap.getIcon("panel_advanced.TabConstraints.tabIcon"), panel_advanced); // NOI18N

        panel_buttons.setName("panel_buttons"); // NOI18N

        javax.swing.ActionMap actionMap = org.jdesktop.application.Application.getInstance(net.yakiboo.yakito.YakiToApp.class).getContext().getActionMap(YakiToView.class, this);
        button_start.setAction(actionMap.get("encodeStartOrPause")); // NOI18N
        button_start.setIcon(resourceMap.getIcon("button_start.icon")); // NOI18N
        button_start.setText(resourceMap.getString("button_start.text")); // NOI18N
        button_start.setActionCommand(resourceMap.getString("button_start.actionCommand")); // NOI18N
        button_start.setName("button_start"); // NOI18N

        button_stop.setAction(actionMap.get("encodeStop")); // NOI18N
        button_stop.setIcon(resourceMap.getIcon("button_stop.icon")); // NOI18N
        button_stop.setText(resourceMap.getString("button_stop.text")); // NOI18N
        button_stop.setName("button_stop"); // NOI18N

        javax.swing.GroupLayout panel_buttonsLayout = new javax.swing.GroupLayout(panel_buttons);
        panel_buttons.setLayout(panel_buttonsLayout);
        panel_buttonsLayout.setHorizontalGroup(
            panel_buttonsLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, panel_buttonsLayout.createSequentialGroup()
                .addContainerGap(javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                .addComponent(button_stop)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(button_start)
                .addContainerGap())
        );
        panel_buttonsLayout.setVerticalGroup(
            panel_buttonsLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, panel_buttonsLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                .addComponent(button_start)
                .addComponent(button_stop))
        );

        jSeparator1.setName("jSeparator1"); // NOI18N

        progressBar.setName("progressBar"); // NOI18N

        jLabel6.setText(resourceMap.getString("jLabel6.text")); // NOI18N
        jLabel6.setName("jLabel6"); // NOI18N

        javax.swing.GroupLayout mainPanelLayout = new javax.swing.GroupLayout(mainPanel);
        mainPanel.setLayout(mainPanelLayout);
        mainPanelLayout.setHorizontalGroup(
            mainPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addComponent(jSeparator1, javax.swing.GroupLayout.DEFAULT_SIZE, 915, Short.MAX_VALUE)
            .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, mainPanelLayout.createSequentialGroup()
                .addContainerGap()
                .addComponent(jLabel6)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED, 558, Short.MAX_VALUE)
                .addComponent(progressBar, javax.swing.GroupLayout.PREFERRED_SIZE, 45, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(panel_buttons, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
            .addComponent(tabs, javax.swing.GroupLayout.Alignment.TRAILING, javax.swing.GroupLayout.DEFAULT_SIZE, 915, Short.MAX_VALUE)
        );
        mainPanelLayout.setVerticalGroup(
            mainPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, mainPanelLayout.createSequentialGroup()
                .addComponent(tabs, javax.swing.GroupLayout.DEFAULT_SIZE, 587, Short.MAX_VALUE)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addGroup(mainPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.TRAILING, false)
                    .addComponent(jLabel6, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                    .addComponent(progressBar, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                    .addComponent(panel_buttons, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(jSeparator1, javax.swing.GroupLayout.PREFERRED_SIZE, 5, javax.swing.GroupLayout.PREFERRED_SIZE))
        );

        menuBar.setName("menuBar"); // NOI18N

        menu_file.setText(resourceMap.getString("menu_file.text")); // NOI18N
        menu_file.setName("menu_file"); // NOI18N

        exitMenuItem.setAction(actionMap.get("quit")); // NOI18N
        exitMenuItem.setText(resourceMap.getString("exitMenuItem.text")); // NOI18N
        exitMenuItem.setName("exitMenuItem"); // NOI18N
        menu_file.add(exitMenuItem);

        menuBar.add(menu_file);

        menu_options.setText(resourceMap.getString("menu_options.text")); // NOI18N
        menu_options.setName("menu_options"); // NOI18N

        menu_concurrent.setText(resourceMap.getString("menu_concurrent.text")); // NOI18N
        menu_concurrent.setName("menu_concurrent"); // NOI18N
        menu_concurrent.addItemListener(new java.awt.event.ItemListener() {
            public void itemStateChanged(java.awt.event.ItemEvent evt) {
                menu_concurrentItemStateChanged(evt);
            }
        });
        menu_concurrent.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                menu_concurrentActionPerformed(evt);
            }
        });
        menu_options.add(menu_concurrent);

        menuBar.add(menu_options);

        menu_help.setText(resourceMap.getString("menu_help.text")); // NOI18N
        menu_help.setName("menu_help"); // NOI18N

        menu_about.setAction(actionMap.get("showAboutBox")); // NOI18N
        menu_about.setText(resourceMap.getString("menu_about.text")); // NOI18N
        menu_about.setName("menu_about"); // NOI18N
        menu_help.add(menu_about);

        menuBar.add(menu_help);

        statusPanel.setName("statusPanel"); // NOI18N

        statusPanelSeparator.setName("statusPanelSeparator"); // NOI18N

        statusMessageLabel.setText(resourceMap.getString("statusMessageLabel.text")); // NOI18N
        statusMessageLabel.setName("statusMessageLabel"); // NOI18N

        statusAnimationLabel.setHorizontalAlignment(javax.swing.SwingConstants.LEFT);
        statusAnimationLabel.setName("statusAnimationLabel"); // NOI18N

        label_ram.setForeground(resourceMap.getColor("jLabel6.foreground")); // NOI18N
        label_ram.setHorizontalAlignment(javax.swing.SwingConstants.RIGHT);
        label_ram.setText(resourceMap.getString("label_ram.text")); // NOI18N
        label_ram.setName("label_ram"); // NOI18N

        jSeparator2.setOrientation(javax.swing.SwingConstants.VERTICAL);
        jSeparator2.setName("jSeparator2"); // NOI18N

        label_time.setFont(new java.awt.Font("Monospaced", 0, 15)); // NOI18N
        label_time.setForeground(resourceMap.getColor("jLabel6.foreground")); // NOI18N
        label_time.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        label_time.setText(resourceMap.getString("label_time.text")); // NOI18N
        label_time.setName("label_time"); // NOI18N

        label_remaining.setForeground(resourceMap.getColor("jLabel6.foreground")); // NOI18N
        label_remaining.setText(resourceMap.getString("label_remaining.text")); // NOI18N
        label_remaining.setName("label_remaining"); // NOI18N

        label_percent.setHorizontalAlignment(javax.swing.SwingConstants.RIGHT);
        label_percent.setText(resourceMap.getString("label_percent.text")); // NOI18N
        label_percent.setName("label_percent"); // NOI18N

        label_completed.setForeground(resourceMap.getColor("label_completed.foreground")); // NOI18N
        label_completed.setText(resourceMap.getString("label_completed.text")); // NOI18N
        label_completed.setName("label_completed"); // NOI18N

        jSeparator3.setOrientation(javax.swing.SwingConstants.VERTICAL);
        jSeparator3.setName("jSeparator3"); // NOI18N

        javax.swing.GroupLayout statusPanelLayout = new javax.swing.GroupLayout(statusPanel);
        statusPanel.setLayout(statusPanelLayout);
        statusPanelLayout.setHorizontalGroup(
            statusPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(statusPanelLayout.createSequentialGroup()
                .addGroup(statusPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addComponent(statusPanelSeparator, javax.swing.GroupLayout.DEFAULT_SIZE, 374, Short.MAX_VALUE)
                    .addGroup(statusPanelLayout.createSequentialGroup()
                        .addContainerGap()
                        .addComponent(statusAnimationLabel, javax.swing.GroupLayout.PREFERRED_SIZE, 23, javax.swing.GroupLayout.PREFERRED_SIZE)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addComponent(statusMessageLabel)))
                .addGap(85, 85, 85)
                .addComponent(jSeparator3, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(label_completed)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(label_percent, javax.swing.GroupLayout.PREFERRED_SIZE, 51, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(jSeparator2, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(label_remaining)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addGroup(statusPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.TRAILING)
                    .addComponent(label_ram)
                    .addComponent(label_time, javax.swing.GroupLayout.PREFERRED_SIZE, 106, javax.swing.GroupLayout.PREFERRED_SIZE))
                .addContainerGap())
        );
        statusPanelLayout.setVerticalGroup(
            statusPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, statusPanelLayout.createSequentialGroup()
                .addComponent(statusPanelSeparator, javax.swing.GroupLayout.PREFERRED_SIZE, 2, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addGroup(statusPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addGroup(statusPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                        .addComponent(statusMessageLabel, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                        .addComponent(label_ram)
                        .addComponent(label_time)
                        .addComponent(label_remaining)
                        .addComponent(label_percent)
                        .addComponent(label_completed))
                    .addComponent(statusAnimationLabel, javax.swing.GroupLayout.DEFAULT_SIZE, 18, Short.MAX_VALUE))
                .addContainerGap())
            .addComponent(jSeparator2, javax.swing.GroupLayout.DEFAULT_SIZE, 38, Short.MAX_VALUE)
            .addComponent(jSeparator3, javax.swing.GroupLayout.Alignment.TRAILING, javax.swing.GroupLayout.DEFAULT_SIZE, 38, Short.MAX_VALUE)
        );

        setComponent(mainPanel);
        setMenuBar(menuBar);
        setStatusBar(statusPanel);
    }// </editor-fold>//GEN-END:initComponents

	private void button_saveprofileActionPerformed(
			java.awt.event.ActionEvent evt) {// GEN-FIRST:event_button_saveprofileActionPerformed
		String name = textfield_name.getText();
		if (name == null || name.length() < 1) {
			YakiToOutput
					.errorDialog(
							config.getLanguage().getValueOf(
									"dialog_save_profile_title"),
							config.getLanguage().getValueOf(
									"dialog_save_profile_text"));
		} else {
			File f = new File(YakiToFileSystem.getProfilesLocation()
					.getAbsolutePath()
					+ System.getProperty("file.separator")
					+ name + ".profile");
			if (f.exists()) {
				YakiToOutput.errorDialog(
						config.getLanguage().getValueOf(
								"dialog_save_profile_override_title"),
						config.getLanguage().getValueOf(
								"dialog_save_profile_override_text"));
			} else {
				// Creamos el perfil y lo guardamos
				YakiToProfile p = new YakiToProfile(name);
				p.setContainer(((YakiToContainer) combo_container
						.getSelectedItem()).getExtension());
				if (!this.radio_noaudio.isSelected()) {
					if (this.radio_sameaudio.isSelected())
						p.setACodec("copy");
					else {
						p.setACodec("" + this.combo_acodec.getSelectedItem());
						p.setAchannels(this.combo_achannels.getSelectedIndex() + 1);
						p.setAkbps((Integer) this.spinner_akbps.getValue());
						p.setSamplefreq((Integer) this.combo_afreq
								.getSelectedItem());
						p.setVolume(this.slider_volume.getValue());
					}
				}
				if (!this.radio_novideo.isSelected()) {
					if (this.radio_samevideo.isSelected())
						p.setVCodec("copy");
					else {
						p.setVCodec("" + this.combo_vcodec.getSelectedItem());
						p.setVtag(this.combo_vtag.getText());
						if(!this.check_sameq.isSelected()){
							p.setVkbps((Integer)this.spinner_vkbps.getValue());
							p.setFps((Integer)this.spinner_fps.getValue());
						}
						if(this.check_redim.isSelected()){
							if(this.combo_redim.getSelectedIndex() == 0){
								// Redimensionado personalizado
								p.setHsize((Integer)this.spinner_width.getValue());
								p.setVsize((Integer)this.spinner_height.getValue());
							}
						}
					}
				}
				p.setExtraparams(this.textfield_extra.getText());

				p.saveProfileToFile(f);
				YakiToOutput.messageDialog(
						config.getLanguage().getValueOf(
								"dialog_profile_saved_title"),
						config.getLanguage().getValueOf(
								"dialog_profile_saved_text")
								+ "\n\"" + f.getAbsolutePath() + "\"");
				this.textfield_name.setText("");
			}
		}
	}// GEN-LAST:event_button_saveprofileActionPerformed

	private void combo_profileActionPerformed(java.awt.event.ActionEvent evt) {// GEN-FIRST:event_combo_profileActionPerformed

	}// GEN-LAST:event_combo_profileActionPerformed

	private void combo_profilePropertyChange(java.beans.PropertyChangeEvent evt) {// GEN-FIRST:event_combo_profilePropertyChange
		// TODO add your handling code here:
	}// GEN-LAST:event_combo_profilePropertyChange

	private void combo_profileItemStateChanged(java.awt.event.ItemEvent evt) {// GEN-FIRST:event_combo_profileItemStateChanged

		// Obtenemos el perfil que se ha seleccionado
		int index = combo_profile.getSelectedIndex();
		if (index > 0) {
			YakiToProfile p = (YakiToProfile) combo_profile.getSelectedItem();
			config.setLast_profile(p.getName());
			config.saveConfigToXML();
			/* Cargamos todos los parametros del perfil */

			// Contenedor multimedia
			this.combo_container.setSelectedItem(new YakiToContainer(p
					.getContainer()));

			// Parametros de audio
			if (p.getACodec() == null) {
				this.radio_noaudio.setSelected(true);
			} else if (p.getACodec().equals("copy")) {
				this.radio_sameaudio.setSelected(true);
			} else {
				this.combo_acodec.setSelectedItem(p.getACodec());
				if (p.getAkbps() > 0)
					this.spinner_akbps.setValue(p.getAkbps());
				if (p.getSamplefreq() > 0)
					this.combo_afreq.setSelectedItem(p.getSamplefreq());
				if (p.getAchannels() > 0)
					this.combo_achannels.setSelectedIndex(p.getAchannels() - 1);
				if (p.getVolume() >= -100 && p.getVolume() <= 100)
					this.slider_volume.setValue(p.getVolume());
			}

			// Parametros de video
			if (p.getVCodec() == null) {
				this.radio_novideo.setSelected(true);
			} else if (p.getVCodec().equals("copy")) {
				this.radio_samevideo.setSelected(true);
			} else {
				this.radio_recvideo.setSelected(true);
				this.combo_vcodec.setSelectedItem(p.getVCodec());
				if (p.getVkbps() > 0 && p.getFps() > 0) {
					this.spinner_vkbps.setValue(p.getVkbps());
					this.spinner_fps.setValue(p.getFps());
					this.check_sameq.setSelected(false);
				} else {
					this.check_sameq.setSelected(true);
				}
				if (p.getVtag() != null)
					this.combo_vtag.setText(p.getVtag());
				else
					this.combo_vtag.setText("");
				if (p.getVsize() > 0 && p.getHsize() > 0) {
					this.check_redim.setSelected(true);
					this.combo_redim.setSelectedIndex(0);
					this.spinner_width.setValue(p.getHsize());
					this.spinner_height.setValue(p.getVsize());
				} else {
					this.check_redim.setSelected(false);
				}
			}

			// Argumentos adicionales
			if (p.getExtraparams() != null && p.getExtraparams().length() > 0)
				this.textfield_extra.setText(p.getExtraparams());
			else
				this.textfield_extra.setText("");

		}
	}// GEN-LAST:event_combo_profileItemStateChanged

	private void menu_concurrentActionPerformed(java.awt.event.ActionEvent evt) {// GEN-FIRST:event_menu_concurrentActionPerformed
		// TODO add your handling code here:
	}// GEN-LAST:event_menu_concurrentActionPerformed

	private void menu_concurrentItemStateChanged(java.awt.event.ItemEvent evt) {// GEN-FIRST:event_menu_concurrentItemStateChanged
		conversion.setConcurrent(menu_concurrent.isSelected());
		button_down.setEnabled(!menu_concurrent.isSelected());
		button_up.setEnabled(!menu_concurrent.isSelected());
	}// GEN-LAST:event_menu_concurrentItemStateChanged

	private void button_addActionPerformed(java.awt.event.ActionEvent evt) {// GEN-FIRST:event_button_addActionPerformed
		JFileChooser fc = new JFileChooser();
		fc.setMultiSelectionEnabled(true);
		fc.setFileSelectionMode(JFileChooser.FILES_AND_DIRECTORIES);
		fc.showOpenDialog(getComponent());
		File[] files = fc.getSelectedFiles();
		if (files != null && files.length > 0) {
			addFilesToTable(files);
		}
		updateTable();
	}// GEN-LAST:event_button_addActionPerformed

	private void button_removeActionPerformed(java.awt.event.ActionEvent evt) {// GEN-FIRST:event_button_removeActionPerformed
		removeSelectedFiles();
	}// GEN-LAST:event_button_removeActionPerformed

	private void button_upActionPerformed(java.awt.event.ActionEvent evt) {// GEN-FIRST:event_button_upActionPerformed
		up();
	}// GEN-LAST:event_button_upActionPerformed

	private void button_downActionPerformed(java.awt.event.ActionEvent evt) {// GEN-FIRST:event_button_downActionPerformed
		down();
	}// GEN-LAST:event_button_downActionPerformed

	private void button_clearActionPerformed(java.awt.event.ActionEvent evt) {// GEN-FIRST:event_button_clearActionPerformed
		clearList();
	}// GEN-LAST:event_button_clearActionPerformed

	private void check_sameqItemStateChanged(java.awt.event.ItemEvent evt) {// GEN-FIRST:event_check_sameqItemStateChanged
		boolean b = !check_sameq.isSelected() && radio_recvideo.isSelected();
		spinner_vkbps.setEnabled(b);
		spinner_fps.setEnabled(b);
	}// GEN-LAST:event_check_sameqItemStateChanged

	private void check_redimItemStateChanged(java.awt.event.ItemEvent evt) {// GEN-FIRST:event_check_redimItemStateChanged
		boolean b = check_redim.isSelected();
		combo_redim.setEnabled(b);
		b = b && (combo_redim.getSelectedIndex() == 0);
		spinner_height.setEnabled(b);
		spinner_width.setEnabled(b);
	}// GEN-LAST:event_check_redimItemStateChanged

	private void combo_redimItemStateChanged(java.awt.event.ItemEvent evt) {// GEN-FIRST:event_combo_redimItemStateChanged
		boolean b = combo_redim.getSelectedIndex() == 0;
		b = b && check_redim.isSelected();
		spinner_width.setEnabled(b);
		spinner_height.setEnabled(b);
	}// GEN-LAST:event_combo_redimItemStateChanged

	private void button_browseActionPerformed(java.awt.event.ActionEvent evt) {// GEN-FIRST:event_button_browseActionPerformed
		JFileChooser fc = new JFileChooser();
		fc.setFileSelectionMode(JFileChooser.DIRECTORIES_ONLY);
		fc.setSelectedFile(new File(conversion.getDestiny()));
		fc.showOpenDialog(this.getComponent());
		File f = fc.getSelectedFile();
		if (f != null) {
			config.setLastDestiny(f);
			conversion.setDestiny(f.getAbsolutePath());
			jTextField1.setText(f.getAbsolutePath());
		}
		config.saveConfigToXML();
	}// GEN-LAST:event_button_browseActionPerformed

	private void radio_sameaudioItemStateChanged(java.awt.event.ItemEvent evt) {// GEN-FIRST:event_radio_sameaudioItemStateChanged
		enableOrDisableAudioParameters(!radio_sameaudio.isSelected());
	}// GEN-LAST:event_radio_sameaudioItemStateChanged

	private void radio_noaudioItemStateChanged(java.awt.event.ItemEvent evt) {// GEN-FIRST:event_radio_noaudioItemStateChanged
		enableOrDisableAudioParameters(!radio_noaudio.isSelected());
	}// GEN-LAST:event_radio_noaudioItemStateChanged

	private void radio_recaudioItemStateChanged(java.awt.event.ItemEvent evt) {// GEN-FIRST:event_radio_recaudioItemStateChanged
		enableOrDisableAudioParameters(radio_recaudio.isSelected());
	}// GEN-LAST:event_radio_recaudioItemStateChanged

	private void radio_recvideoItemStateChanged(java.awt.event.ItemEvent evt) {// GEN-FIRST:event_radio_recvideoItemStateChanged
		enableOrDisableVideoParameters(radio_recvideo.isEnabled());
		check_sameq.setEnabled(radio_recvideo.isSelected());
	}// GEN-LAST:event_radio_recvideoItemStateChanged

	private void radio_samevideoItemStateChanged(java.awt.event.ItemEvent evt) {// GEN-FIRST:event_radio_samevideoItemStateChanged
		enableOrDisableVideoParameters(!radio_samevideo.isEnabled());
	}// GEN-LAST:event_radio_samevideoItemStateChanged

	private void radio_novideoItemStateChanged(java.awt.event.ItemEvent evt) {// GEN-FIRST:event_radio_novideoItemStateChanged
		enableOrDisableVideoParameters(!radio_novideo.isSelected());
	}// GEN-LAST:event_radio_novideoItemStateChanged

	private void mainPanelComponentResized(java.awt.event.ComponentEvent evt) {// GEN-FIRST:event_mainPanelComponentResized
		// panel_buttons.setLocation(panel_buttons.getLocation().x,
		// panel_buttons.getLocation().y + 3);
		splitPane_horizontal.setDividerLocation(0.45);

	}// GEN-LAST:event_mainPanelComponentResized

	private void jMenuItem1ActionPerformed(java.awt.event.ActionEvent evt) {// GEN-FIRST:event_jMenuItem1ActionPerformed
		pruebas();
	}// GEN-LAST:event_jMenuItem1ActionPerformed

    // Variables declaration - do not modify//GEN-BEGIN:variables
    private javax.swing.ButtonGroup buttonGroup1;
    private javax.swing.ButtonGroup buttonGroup2;
    private javax.swing.JButton button_add;
    private javax.swing.JButton button_browse;
    private javax.swing.JButton button_clear;
    private javax.swing.JButton button_down;
    private javax.swing.JButton button_remove;
    private javax.swing.JButton button_saveprofile;
    private javax.swing.JButton button_start;
    private javax.swing.JButton button_stop;
    private javax.swing.JButton button_up;
    private javax.swing.JCheckBox check_redim;
    private javax.swing.JCheckBox check_sameq;
    private javax.swing.JComboBox combo_achannels;
    private javax.swing.JComboBox combo_acodec;
    private javax.swing.JComboBox combo_afreq;
    private javax.swing.JComboBox combo_container;
    private javax.swing.JComboBox combo_profile;
    private javax.swing.JComboBox combo_redim;
    private javax.swing.JComboBox combo_vcodec;
    private javax.swing.JTextField combo_vtag;
    private javax.swing.JLabel jLabel11;
    private javax.swing.JLabel jLabel13;
    private javax.swing.JLabel jLabel16;
    private javax.swing.JLabel jLabel17;
    private javax.swing.JLabel jLabel22;
    private javax.swing.JLabel jLabel23;
    private javax.swing.JLabel jLabel5;
    private javax.swing.JLabel jLabel6;
    private javax.swing.JPanel jPanel2;
    private javax.swing.JPanel jPanel6;
    private javax.swing.JPanel jPanel7;
    private javax.swing.JScrollPane jScrollPane1;
    private javax.swing.JSeparator jSeparator1;
    private javax.swing.JSeparator jSeparator2;
    private javax.swing.JSeparator jSeparator3;
    private javax.swing.JSeparator jSeparator4;
    private javax.swing.JSeparator jSeparator5;
    private javax.swing.JSeparator jSeparator6;
    private javax.swing.JSeparator jSeparator7;
    private javax.swing.JTextField jTextField1;
    private javax.swing.JLabel label_achannels;
    private javax.swing.JLabel label_acodec;
    private javax.swing.JLabel label_afreq;
    private javax.swing.JLabel label_akbps;
    private javax.swing.JLabel label_completed;
    private javax.swing.JLabel label_name;
    private javax.swing.JLabel label_percent;
    private javax.swing.JLabel label_ram;
    private javax.swing.JLabel label_remaining;
    private javax.swing.JLabel label_time;
    private javax.swing.JLabel label_vcodec;
    private javax.swing.JLabel label_vkbps;
    private javax.swing.JLabel label_volume;
    private javax.swing.JLabel label_vtag;
    private javax.swing.JPanel mainPanel;
    private javax.swing.JMenuBar menuBar;
    private javax.swing.JCheckBoxMenuItem menu_concurrent;
    private javax.swing.JMenu menu_options;
    private javax.swing.JPanel panel_advanced;
    private javax.swing.JPanel panel_audio;
    private javax.swing.JPanel panel_basic;
    private javax.swing.JPanel panel_buttons;
    private javax.swing.JPanel panel_container;
    private javax.swing.JPanel panel_destiny;
    private javax.swing.JPanel panel_extra;
    private javax.swing.JPanel panel_profile;
    private javax.swing.JPanel panel_saveprofile;
    private javax.swing.JPanel panel_table;
    private javax.swing.JPanel panel_video;
    private javax.swing.JProgressBar progressBar;
    private javax.swing.JRadioButton radio_noaudio;
    private javax.swing.JRadioButton radio_novideo;
    private javax.swing.JRadioButton radio_recaudio;
    private javax.swing.JRadioButton radio_recvideo;
    private javax.swing.JRadioButton radio_sameaudio;
    private javax.swing.JRadioButton radio_samevideo;
    private javax.swing.JSlider slider_volume;
    private javax.swing.JSpinner spinner_akbps;
    private javax.swing.JSpinner spinner_fps;
    private javax.swing.JSpinner spinner_height;
    private javax.swing.JSpinner spinner_vkbps;
    private javax.swing.JSpinner spinner_width;
    private javax.swing.JSplitPane splitPane_horizontal;
    private javax.swing.JLabel statusAnimationLabel;
    private javax.swing.JLabel statusMessageLabel;
    private javax.swing.JPanel statusPanel;
    private javax.swing.JTable table;
    private javax.swing.JTabbedPane tabs;
    private javax.swing.JTextField textfield_extra;
    private javax.swing.JTextField textfield_name;
    // End of variables declaration//GEN-END:variables

	private final Timer messageTimer;
	private final Timer busyIconTimer;
	private final Icon idleIcon;
	private final Icon[] busyIcons = new Icon[15];
	private int busyIconIndex = 0;

	private JDialog aboutBox;

	@Override
	public void updateProgressBars() {
		SwingUtilities.invokeLater(new Runnable() {
			public void run() {
				table.updateUI();
			}
		});
		/*
		 * for(int i=0; i < table.getRowCount(); i++){ JProgressBar bar =
		 * (JProgressBar)table.getModel().getValueAt(i,
		 * table.getColumnCount()-1); bar.updateUI(); }
		 */

	}

	@Override
	public void setTotalProgress(final int value) {
		SwingUtilities.invokeLater(new Runnable() {
			public void run() {				
				label_percent.setText(value + "%");
				if(value == 100) setRemainingTime(0);
			}
		});

	}

	@Override
	public void setRemainingTime(int seconds) {
		int minutos = seconds / 60;
		seconds = seconds % 60;
		int horas = minutos / 60;
		minutos = minutos % 60;		
		String aux = "0" + horas;
		final String h = aux.substring(aux.length() - 2);
		aux = "0" + minutos;
		final String m = aux.substring(aux.length() - 2);
		aux = "0" + seconds;
		final String s = aux.substring(aux.length() - 2);
		SwingUtilities.invokeLater(new Runnable() {
			public void run() {
				label_time.setText(h + "h:" + m + "m:" + s + "s");
			}
		});
	}

}
